"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class OfflineServingQueryOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INCLUDE_FEATURESET_VERSION_COLUMN_FIELD_NUMBER: builtins.int
    include_featureset_version_column: builtins.bool
    """Whether or not to include featureset version as a column in the result set"""
    def __init__(
        self,
        *,
        include_featureset_version_column: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["include_featureset_version_column", b"include_featureset_version_column"]) -> None: ...

global___OfflineServingQueryOptions = OfflineServingQueryOptions



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class ModelRepositoryJFrogSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JFROG_PROJECT_KEY_FIELD_NUMBER: builtins.int
    jfrog_project_key: builtins.str
    """JFrog project key"""
    def __init__(
        self,
        *,
        jfrog_project_key: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["jfrog_project_identifier", b"jfrog_project_identifier", "jfrog_project_key", b"jfrog_project_key"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["jfrog_project_identifier", b"jfrog_project_identifier", "jfrog_project_key", b"jfrog_project_key"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["jfrog_project_identifier", b"jfrog_project_identifier"]) -> typing_extensions.Literal["jfrog_project_key"] | None: ...

global___ModelRepositoryJFrogSpec = ModelRepositoryJFrogSpec



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/builds/build.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.user_application.common.v0 import resources_pb2 as qwak_dot_user__application_dot_common_dot_v0_dot_resources__pb2
from _qwak_proto.qwak.fitness_service import fitness_pb2 as qwak_dot_fitness__service_dot_fitness__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17qwak/builds/build.proto\x12\x18qwak.builds.orchestrator\x1a/qwak/user_application/common/v0/resources.proto\x1a\"qwak/fitness_service/fitness.proto\"\xbf\x06\n\x0fRemoteBuildSpec\x12\x43\n\x10\x62uild_properties\x18\x01 \x01(\x0b\x32).qwak.builds.orchestrator.BuildProperties\x12\x35\n\tbuild_env\x18\x02 \x01(\x0b\x32\".qwak.builds.orchestrator.BuildEnv\x12\x43\n\rcpu_resources\x18\x03 \x01(\x0b\x32&.qwak.builds.orchestrator.CpuResourcesB\x02\x18\x01H\x00\x12\x43\n\rgpu_resources\x18\x07 \x01(\x0b\x32&.qwak.builds.orchestrator.GpuResourcesB\x02\x18\x01H\x00\x12\x62\n\x1c\x63lient_pod_compute_resources\x18\r \x01(\x0b\x32:.qwak.user_application.common.v0.ClientPodComputeResourcesH\x00\x12\x0f\n\x07verbose\x18\x04 \x01(\x05\x12\x17\n\x0f\x62uild_code_path\x18\x05 \x01(\t\x12\x14\n\x0c\x62uild_config\x18\x06 \x01(\t\x12\x15\n\rbuild_v1_flag\x18\x08 \x01(\x08\x12H\n\x13\x62uild_properties_v1\x18\t \x01(\x0b\x32+.qwak.builds.orchestrator.BuildPropertiesV1\x12\x13\n\x0b\x62uild_steps\x18\n \x03(\t\x12\x16\n\x0e\x65nvironment_id\x18\x0b \x01(\t\x12\x13\n\x0bsdk_version\x18\x0c \x01(\t\x12=\n\x0fpurchase_option\x18\x0e \x01(\x0e\x32$.qwak.fitness.service.PurchaseOption\x12\x1c\n\x14\x62uild_destined_image\x18\x0f \x01(\t\x12\"\n\x1aprovision_instance_timeout\x18\x10 \x01(\x05\x12\x16\n\x0ejfrog_token_id\x18\x11 \x01(\t\x12\x1f\n\x17\x61rtifactory_project_key\x18\x12 \x01(\t\x12\x18\n\x10model_version_id\x18\x13 \x01(\tB\x0b\n\tResources\"g\n\x11\x42uildPropertiesV1\x12\x18\n\x10\x62uild_config_url\x18\x01 \x01(\t\x12\x1a\n\x12qwak_sdk_wheel_url\x18\x02 \x01(\t\x12\x1c\n\x14qwak_sdk_version_url\x18\x03 \x01(\t\"\xba\x01\n\x0f\x42uildProperties\x12\x10\n\x08\x62uild_id\x18\x01 \x01(\t\x12\x0e\n\x06\x62ranch\x18\x02 \x01(\t\x12\x10\n\x08model_id\x18\x03 \x01(\t\x12\x0c\n\x04tags\x18\x04 \x03(\t\x12\x39\n\tmodel_uri\x18\x05 \x01(\x0b\x32&.qwak.builds.orchestrator.ModelUriSpec\x12\x16\n\x0egpu_compatible\x18\x06 \x01(\x08\x12\x12\n\nbuild_name\x18\x07 \x01(\t\"\xb2\x01\n\x0cModelUriSpec\x12\x0b\n\x03uri\x18\x01 \x01(\t\x12\x12\n\ngit_branch\x18\x02 \x01(\t\x12\x17\n\x0fgit_credentials\x18\x03 \x01(\t\x12\x1e\n\x16git_credentials_secret\x18\x04 \x01(\t\x12\x11\n\tcommit_id\x18\x05 \x01(\t\x12\x10\n\x08main_dir\x18\x06 \x01(\t\x12#\n\x1b\x64\x65pendency_required_folders\x18\x07 \x03(\t\"|\n\x08\x42uildEnv\x12\x37\n\ndocker_env\x18\x01 \x01(\x0b\x32#.qwak.builds.orchestrator.DockerEnv\x12\x37\n\npython_env\x18\x02 \x01(\x0b\x32#.qwak.builds.orchestrator.PythonEnv\"\x8a\x01\n\tDockerEnv\x12\x12\n\nbase_image\x18\x01 \x01(\t\x12\x10\n\x08\x65nv_vars\x18\x02 \x03(\t\x12\x10\n\x08no_cache\x18\x03 \x01(\x08\x12\x1c\n\x14\x61ssumed_iam_role_arn\x18\x04 \x01(\t\x12\'\n\x1fservice_account_key_secret_name\x18\x05 \x01(\t\"\xb8\x01\n\tPythonEnv\x12\x17\n\x0fgit_credentials\x18\x01 \x01(\t\x12\x1e\n\x16git_credentials_secret\x18\x02 \x01(\t\x12\x18\n\x10qwak_sdk_version\x18\x03 \x01(\t\x12\x1c\n\x14qwak_sdk_extra_index\x18\x04 \x01(\t\x12\x1a\n\x12\x66rogml_cli_version\x18\x05 \x01(\t\x12\x1e\n\x16\x66rogml_cli_extra_index\x18\x06 \x01(\t\"n\n\x0c\x43puResources\x12\x0b\n\x03\x63pu\x18\x01 \x01(\x02\x12\x15\n\rmemory_amount\x18\x02 \x01(\x05\x12:\n\x0cmemory_units\x18\x03 \x01(\x0e\x32$.qwak.builds.orchestrator.MemoryUnit\"W\n\x0cGpuResources\x12\x33\n\x08gpu_type\x18\x01 \x01(\x0e\x32!.qwak.builds.orchestrator.GpuType\x12\x12\n\ngpu_amount\x18\x02 \x01(\x05\"\x91\x01\n\x13\x44\x61taTableDefinition\x12?\n\x07\x63olumns\x18\x01 \x03(\x0b\x32..qwak.builds.orchestrator.DataColumnDefinition\x12\x39\n\x0b\x64\x61ta_format\x18\x02 \x01(\x0b\x32$.qwak.builds.orchestrator.DataFormat\"\\\n\x14\x44\x61taColumnDefinition\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x36\n\x04type\x18\x02 \x01(\x0e\x32(.qwak.builds.orchestrator.DataColumnType\"J\n\nDataFormat\x12\x32\n\x03\x63sv\x18\x01 \x01(\x0b\x32#.qwak.builds.orchestrator.CsvFormatH\x00\x42\x08\n\x06\x66ormat\"G\n\tCsvFormat\x12\x11\n\tdelimiter\x18\x01 \x01(\t\x12\x12\n\nquote_char\x18\x02 \x01(\t\x12\x13\n\x0b\x65scape_char\x18\x03 \x01(\t\"\xa5\x01\n\x0e\x42uildInitiator\x12<\n\x04user\x18\x01 \x01(\x0b\x32,.qwak.builds.orchestrator.UserBuildInitiatorH\x00\x12H\n\nautomation\x18\x02 \x01(\x0b\x32\x32.qwak.builds.orchestrator.AutomationBuildInitiatorH\x00\x42\x0b\n\tInitiator\"\x14\n\x12UserBuildInitiator\"`\n\x18\x41utomationBuildInitiator\x12\x15\n\rautomation_id\x18\x01 \x01(\t\x12\x14\n\x0c\x65xecution_id\x18\x02 \x01(\t\x12\x17\n\x0f\x61utomation_name\x18\x03 \x01(\t*7\n\nMemoryUnit\x12\x17\n\x13UNKNOWN_MEMORY_UNIT\x10\x00\x12\x07\n\x03MIB\x10\x01\x12\x07\n\x03GIB\x10\x02*\x8c\x02\n\x07GpuType\x12\x0b\n\x07INVALID\x10\x00\x12\x0e\n\nNVIDIA_K80\x10\x01\x12\x0f\n\x0bNVIDIA_V100\x10\x02\x12\x0f\n\x0bNVIDIA_A100\x10\x03\x12\r\n\tNVIDIA_T4\x10\x04\x12\x0f\n\x0bNVIDIA_A10G\x10\x05\x12\r\n\tNVIDIA_L4\x10\x06\x12\x14\n\x10NVIDIA_T4_1_4_15\x10\x07\x12\x14\n\x10NVIDIA_T4_1_8_30\x10\x08\x12\x15\n\x11NVIDIA_T4_1_16_60\x10\t\x12\x1e\n\x1aNVIDIA_A100_80GB_8_96_1360\x10\n\x12\x16\n\x12NVIDIA_V100_1_8_52\x10\x0b\x12\x18\n\x14NVIDIA_V100_4_32_208\x10\x0c*d\n\x0e\x44\x61taColumnType\x12\x17\n\x13INVALID_COLUMN_TYPE\x10\x00\x12\n\n\x06OBJECT\x10\x01\x12\x07\n\x03INT\x10\x02\x12\t\n\x05\x46LOAT\x10\x03\x12\x0b\n\x07\x42OOLEAN\x10\x04\x12\x0c\n\x08\x44\x41TETIME\x10\x05*K\n\x13\x42\x61seDockerImageType\x12\"\n\x1eUNKNOWN_BASE_DOCKER_IMAGE_TYPE\x10\x00\x12\x07\n\x03\x43PU\x10\x01\x12\x07\n\x03GPU\x10\x02\x42\'\n#com.qwak.ai.builds.orchestrator.apiP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.builds.build_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#com.qwak.ai.builds.orchestrator.apiP\001'
  _REMOTEBUILDSPEC.fields_by_name['cpu_resources']._options = None
  _REMOTEBUILDSPEC.fields_by_name['cpu_resources']._serialized_options = b'\030\001'
  _REMOTEBUILDSPEC.fields_by_name['gpu_resources']._options = None
  _REMOTEBUILDSPEC.fields_by_name['gpu_resources']._serialized_options = b'\030\001'
  _globals['_MEMORYUNIT']._serialized_start=2781
  _globals['_MEMORYUNIT']._serialized_end=2836
  _globals['_GPUTYPE']._serialized_start=2839
  _globals['_GPUTYPE']._serialized_end=3107
  _globals['_DATACOLUMNTYPE']._serialized_start=3109
  _globals['_DATACOLUMNTYPE']._serialized_end=3209
  _globals['_BASEDOCKERIMAGETYPE']._serialized_start=3211
  _globals['_BASEDOCKERIMAGETYPE']._serialized_end=3286
  _globals['_REMOTEBUILDSPEC']._serialized_start=139
  _globals['_REMOTEBUILDSPEC']._serialized_end=970
  _globals['_BUILDPROPERTIESV1']._serialized_start=972
  _globals['_BUILDPROPERTIESV1']._serialized_end=1075
  _globals['_BUILDPROPERTIES']._serialized_start=1078
  _globals['_BUILDPROPERTIES']._serialized_end=1264
  _globals['_MODELURISPEC']._serialized_start=1267
  _globals['_MODELURISPEC']._serialized_end=1445
  _globals['_BUILDENV']._serialized_start=1447
  _globals['_BUILDENV']._serialized_end=1571
  _globals['_DOCKERENV']._serialized_start=1574
  _globals['_DOCKERENV']._serialized_end=1712
  _globals['_PYTHONENV']._serialized_start=1715
  _globals['_PYTHONENV']._serialized_end=1899
  _globals['_CPURESOURCES']._serialized_start=1901
  _globals['_CPURESOURCES']._serialized_end=2011
  _globals['_GPURESOURCES']._serialized_start=2013
  _globals['_GPURESOURCES']._serialized_end=2100
  _globals['_DATATABLEDEFINITION']._serialized_start=2103
  _globals['_DATATABLEDEFINITION']._serialized_end=2248
  _globals['_DATACOLUMNDEFINITION']._serialized_start=2250
  _globals['_DATACOLUMNDEFINITION']._serialized_end=2342
  _globals['_DATAFORMAT']._serialized_start=2344
  _globals['_DATAFORMAT']._serialized_end=2418
  _globals['_CSVFORMAT']._serialized_start=2420
  _globals['_CSVFORMAT']._serialized_end=2491
  _globals['_BUILDINITIATOR']._serialized_start=2494
  _globals['_BUILDINITIATOR']._serialized_end=2659
  _globals['_USERBUILDINITIATOR']._serialized_start=2661
  _globals['_USERBUILDINITIATOR']._serialized_end=2681
  _globals['_AUTOMATIONBUILDINITIATOR']._serialized_start=2683
  _globals['_AUTOMATIONBUILDINITIATOR']._serialized_end=2779
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/instance_template/instance_template_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.instance_template import instance_template_pb2 as qwak_dot_instance__template_dot_instance__template__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6qwak/instance_template/instance_template_service.proto\x12!qwak.management.instance_template\x1a.qwak/instance_template/instance_template.proto\"s\n\x1cListInstanceTemplatesRequest\x12S\n\x18optional_instance_filter\x18\x01 \x01(\x0b\x32\x31.qwak.management.instance_template.InstanceFilter\"x\n\x1dListInstanceTemplatesResponse\x12W\n\x16instance_template_list\x18\x01 \x03(\x0b\x32\x37.qwak.management.instance_template.InstanceTemplateSpec\"(\n\x1aGetInstanceTemplateRequest\x12\n\n\x02id\x18\x01 \x01(\t\"q\n\x1bGetInstanceTemplateResponse\x12R\n\x11instance_template\x18\x01 \x01(\x0b\x32\x37.qwak.management.instance_template.InstanceTemplateSpec2\xd7\x02\n!InstanceTemplateManagementService\x12\x9a\x01\n\x15ListInstanceTemplates\x12?.qwak.management.instance_template.ListInstanceTemplatesRequest\x1a@.qwak.management.instance_template.ListInstanceTemplatesResponse\x12\x94\x01\n\x13GetInstanceTemplate\x12=.qwak.management.instance_template.GetInstanceTemplateRequest\x1a>.qwak.management.instance_template.GetInstanceTemplateResponseB0\n,com.qwak.ai.management.instance_template.apiP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.instance_template.instance_template_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n,com.qwak.ai.management.instance_template.apiP\001'
  _globals['_LISTINSTANCETEMPLATESREQUEST']._serialized_start=141
  _globals['_LISTINSTANCETEMPLATESREQUEST']._serialized_end=256
  _globals['_LISTINSTANCETEMPLATESRESPONSE']._serialized_start=258
  _globals['_LISTINSTANCETEMPLATESRESPONSE']._serialized_end=378
  _globals['_GETINSTANCETEMPLATEREQUEST']._serialized_start=380
  _globals['_GETINSTANCETEMPLATEREQUEST']._serialized_end=420
  _globals['_GETINSTANCETEMPLATERESPONSE']._serialized_start=422
  _globals['_GETINSTANCETEMPLATERESPONSE']._serialized_end=535
  _globals['_INSTANCETEMPLATEMANAGEMENTSERVICE']._serialized_start=538
  _globals['_INSTANCETEMPLATEMANAGEMENTSERVICE']._serialized_end=881
# @@protoc_insertion_point(module_scope)



from qwak.feature_store.data_sources.streaming.kafka.authentication import (
    PlainAuthentication,
    SaslAuthentication,
    SaslMechanism,
    SecurityProtocol,
    SslAuthentication,
)
from qwak.feature_store.data_sources.streaming.kafka.deserialization import (
    CustomDeserializer,
    GenericDeserializer,
    MessageFormat,
)
from qwak.feature_store.data_sources.streaming.kafka.kafka import KafkaSource

__all__ = [
    "KafkaSource",
    "CustomDeserializer",
    "GenericDeserializer",
    "SaslAuthentication",
    "SslAuthentication",
    "PlainAuthentication",
    "MessageFormat",
    "SaslMechanism",
    "SecurityProtocol",
]



from _qwak_proto.qwak.ecosystem.v0.credentials_pb2 import (
    AwsTemporaryCredentials,
    CloudCredentials,
)
from _qwak_proto.qwak.ecosystem.v0.ecosystem_runtime_service_pb2 import (
    GetAuthenticatedUserContextResponse,
    GetCloudCredentialsResponse,
)
from _qwak_proto.qwak.ecosystem.v0.ecosystem_runtime_service_pb2_grpc import (
    QwakEcosystemRuntimeServicer,
)
from qwak_services_mock.mocks.utils.exception_handlers import raise_internal_grpc_error


class EcoSystemServiceMock(QwakEcosystemRuntimeServicer):
    def __init__(self):
        self._aws_temp_credentials = None
        self._authenticated_user_context = None
        super(EcoSystemServiceMock, self).__init__()

    def given_credentials(self, aws_temp_credentials: AwsTemporaryCredentials):
        self._aws_temp_credentials: AwsTemporaryCredentials = aws_temp_credentials

    def GetCloudCredentials(self, request, context):
        """get cloud credentials"""
        try:
            return GetCloudCredentialsResponse(
                cloud_credentials=CloudCredentials(
                    aws_temporary_credentials=self._aws_temp_credentials
                )
            )
        except Exception as e:
            raise_internal_grpc_error(context, e)

    def given_authenticated_user_context(
        self, authenticated_user_context: GetAuthenticatedUserContextResponse
    ):
        self._authenticated_user_context = authenticated_user_context

    def GetAuthenticatedUserContext(
        self, request, context
    ) -> GetAuthenticatedUserContextResponse:
        return self._authenticated_user_context



import logging
import time
from abc import ABC, abstractmethod
from random import randint
from typing import Callable, Optional, Tuple

import grpc
from qwak.exceptions import QwakException
from qwak.inner.di_configuration.account import UserAccountConfiguration
from qwak.inner.tool.auth import Auth0ClientBase

from .grpc_auth import Auth0Client, FrogMLGrpcClient

logger = logging.getLogger()


def create_grpc_channel(
    url: str,
    enable_ssl: bool = True,
    enable_auth: bool = True,
    auth_metadata_plugin: grpc.AuthMetadataPlugin = None,
    timeout: int = 100,
    options=None,
    backoff_options={},
    max_attempts=4,
    status_for_retry=(grpc.StatusCode.UNAVAILABLE,),
    attempt=0,
) -> grpc.Channel:
    """
    Create a gRPC channel
    Args:
        url: gRPC URL to connect to
        enable_ssl: Enable TLS/SSL, optionally provide a server side certificate
        enable_auth: Enable user auth
        auth_metadata_plugin: Metadata plugin to use to sign requests, only used
            with "enable auth" when SSL/TLS is enabled
        timeout: Connection timeout to server
        options:  An optional list of key-value pairs (channel_arguments in gRPC Core runtime) to configure the channel.
        backoff_options: dictionary - init_backoff_ms: default 50, max_backoff_ms: default 500, multiplier: default 2
        max_attempts: max number of retry attempts
        attempt: current retry attempts
        status_for_retry: grpc statuses to retry upon
    Returns: Returns a grpc.Channel
    """
    if not url:
        raise QwakException("Unable to create gRPC channel. URL has not been defined.")

    if enable_ssl or url.endswith(":443"):
        credentials = grpc.ssl_channel_credentials()
        if enable_auth:
            if auth_metadata_plugin is None:
                user_config = UserAccountConfiguration()
                if issubclass(user_config._auth_client, Auth0ClientBase):
                    auth_metadata_plugin = Auth0Client()
                else:
                    auth_metadata_plugin = FrogMLGrpcClient()
            credentials = grpc.composite_channel_credentials(
                credentials, grpc.metadata_call_credentials(auth_metadata_plugin)
            )

        channel = grpc.secure_channel(url, credentials=credentials, options=options)
    else:
        channel = grpc.insecure_channel(url, options=options)
    try:
        interceptors = (
            RetryOnRpcErrorClientInterceptor(
                max_attempts=max_attempts,
                sleeping_policy=ExponentialBackoff(**backoff_options),
                status_for_retry=status_for_retry,
            ),
        )

        intercept_channel = grpc.intercept_channel(channel, *interceptors)
        try:
            grpc.channel_ready_future(intercept_channel).result(timeout=timeout)
        except (grpc.FutureTimeoutError, grpc.RpcError, Exception) as e:
            logger.debug(
                f"Received error: {repr(e)} attempt #{attempt + 1} of {max_attempts}"
            )
            if attempt < max_attempts:
                return create_grpc_channel(
                    url,
                    enable_ssl,
                    enable_auth,
                    auth_metadata_plugin,
                    timeout,
                    options,
                    backoff_options,
                    max_attempts,
                    status_for_retry,
                    attempt + 1,
                )
            else:
                raise e

        return intercept_channel
    except grpc.FutureTimeoutError as e:
        raise QwakException(
            f"Connection timed out while attempting to connect to {url}, with: {repr(e)}"
        ) from e


def create_grpc_channel_or_none(
    url: str,
    enable_ssl: bool = True,
    enable_auth: bool = True,
    auth_metadata_plugin: grpc.AuthMetadataPlugin = None,
    timeout: int = 30,
    options=None,
    backoff_options={},
    max_attempts=2,
    status_for_retry=(grpc.StatusCode.UNAVAILABLE,),
    attempt=0,
) -> Callable[[Optional[str], Optional[bool]], Optional[grpc.Channel]]:
    def deferred_channel(
        url_overwrite: Optional[str] = None, ssl_overwrite: Optional[bool] = None
    ):
        try:
            return create_grpc_channel(
                url_overwrite if url_overwrite else url,
                ssl_overwrite if ssl_overwrite else enable_ssl,
                enable_auth,
                auth_metadata_plugin,
                timeout,
                options,
                backoff_options,
                max_attempts,
                status_for_retry,
                attempt,
            )
        except Exception as e:
            logger.debug(f"create_grpc_channel error: {repr(e)}")
            return None

    return deferred_channel


class SleepingPolicy(ABC):
    @abstractmethod
    def sleep(self, try_i: int):
        """
        How long to sleep in milliseconds.
        :param try_i: the number of retry (starting from zero)
        """
        if try_i < 0:
            raise ValueError("Number of retries must be non-negative.")


class ExponentialBackoff(SleepingPolicy):
    def __init__(
        self,
        *,
        init_backoff_ms: int = 50,
        max_backoff_ms: int = 5000,
        multiplier: int = 2,
    ):
        self.init_backoff = init_backoff_ms
        self.max_backoff = max_backoff_ms
        self.multiplier = multiplier

    def sleep(self, try_i: int):
        sleep_time = min(self.init_backoff * self.multiplier**try_i, self.max_backoff)
        sleep_ms = sleep_time + randint(0, self.init_backoff)  # nosec B311
        logger.debug("ExponentialBackoff - Sleeping between retries")
        time.sleep(sleep_ms / 1000)


class RetryOnRpcErrorClientInterceptor(grpc.UnaryUnaryClientInterceptor):
    def __init__(
        self,
        *,
        max_attempts: int,
        sleeping_policy: SleepingPolicy,
        status_for_retry: Optional[Tuple[grpc.StatusCode]] = None,
    ):
        self.max_attempts = max_attempts
        self.sleeping_policy = sleeping_policy
        self.status_for_retry = status_for_retry

    def _intercept_call(self, continuation, client_call_details, request_or_iterator):
        for try_i in range(self.max_attempts):
            response = continuation(client_call_details, request_or_iterator)

            if isinstance(response, grpc.RpcError):
                # Return if it was last attempt
                if try_i == (self.max_attempts - 1):
                    return response

                # If status code is not in retryable status codes
                if (
                    self.status_for_retry
                    and response.code() not in self.status_for_retry
                ):
                    return response
                logger.debug(
                    f"Retry GRPC call attempt #{try_i} after status {response.code()}"
                )
                logger.debug(f"Client call details: {client_call_details}")
                self.sleeping_policy.sleep(try_i)
            else:
                return response

    def intercept_unary_unary(self, continuation, client_call_details, request):
        return self._intercept_call(continuation, client_call_details, request)



from typing import List

from _qwak_proto.qwak.integration.integration_pb2 import Integration
from qwak.clients.integration_management.integration_manager_client import (
    IntegrationManagerClient,
)
from qwak.clients.integration_management.openai.openai_system_secret import (
    OpenAIApiKeySystemSecret,
)


class IntegrationUtils:
    def __init__(self):
        self._client: IntegrationManagerClient = IntegrationManagerClient()

    def get_openai_api_keys(self) -> List[OpenAIApiKeySystemSecret]:
        all_integrations: List[Integration] = self._client.list_integrations()

        openai_integration: List[Integration] = [
            i for i in all_integrations if i.WhichOneof("type") == "openai_integration"
        ]

        openai_secrets: List[OpenAIApiKeySystemSecret] = [
            OpenAIApiKeySystemSecret.from_proto(proto=o) for o in openai_integration
        ]

        return [s for s in openai_secrets if s is not None]



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import qwak.administration.runtime_configuration.v0.creds.auth_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class RedisConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASIC_FIELD_NUMBER: builtins.int
    ADDRESS_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    @property
    def basic(self) -> qwak.administration.runtime_configuration.v0.creds.auth_pb2.BasicAuth: ...
    address: builtins.str
    port: builtins.int
    def __init__(
        self,
        *,
        basic: qwak.administration.runtime_configuration.v0.creds.auth_pb2.BasicAuth | None = ...,
        address: builtins.str = ...,
        port: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["auth_type", b"auth_type", "basic", b"basic"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["address", b"address", "auth_type", b"auth_type", "basic", b"basic", "port", b"port"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["auth_type", b"auth_type"]) -> typing_extensions.Literal["basic"] | None: ...

global___RedisConfiguration = RedisConfiguration



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/integration/pagerduty_integration.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,qwak/integration/pagerduty_integration.proto\x12\x1bqwak.integration.management\"\xf4\x01\n\x14PagerdutyIntegration\x12]\n\x1f\x65ncrypted_pagerduty_auth_config\x18\x01 \x01(\x0b\x32\x30.qwak.integration.management.PagerdutyAuthConfigB\x02\x18\x01\x12\x14\n\x0c\x65ndpoint_url\x18\x02 \x01(\t\x12_\n\x17pagerduty_system_secret\x18\x03 \x01(\x0b\x32<.qwak.integration.management.PagerdutySystemSecretDescriptorH\x00\x42\x06\n\x04\x61uth\"|\n\x18PagerdutyIntegrationSpec\x12X\n\x1cpagerduty_auth_configuration\x18\x01 \x01(\x0b\x32\x30.qwak.integration.management.PagerdutyAuthConfigH\x00\x42\x06\n\x04\x61uth\"\xd3\x01\n\x13PagerdutyAuthConfig\x12Y\n\x15\x65vents_v1_auth_config\x18\x01 \x01(\x0b\x32\x38.qwak.integration.management.PagerdutyEventsV1AuthConfigH\x00\x12Y\n\x15\x65vents_v2_auth_config\x18\x02 \x01(\x0b\x32\x38.qwak.integration.management.PagerdutyEventsV2AuthConfigH\x00\x42\x06\n\x04\x61uth\"2\n\x1bPagerdutyEventsV1AuthConfig\x12\x13\n\x0bservice_key\x18\x01 \x01(\t\"2\n\x1bPagerdutyEventsV2AuthConfig\x12\x13\n\x0brouting_key\x18\x01 \x01(\t\"\xb0\x02\n\x1fPagerdutySystemSecretDescriptor\x12\x13\n\x0bsecret_name\x18\x01 \x01(\t\x12q\n!pagerduty_events_v1_system_secret\x18\x02 \x01(\x0b\x32\x44.qwak.integration.management.PagerdutyEventsV1SystemSecretDescriptorH\x00\x12q\n!pagerduty_events_v2_system_secret\x18\x03 \x01(\x0b\x32\x44.qwak.integration.management.PagerdutyEventsV2SystemSecretDescriptorH\x00\x42\x12\n\x10pagerduty_secret\"I\n\'PagerdutyEventsV1SystemSecretDescriptor\x12\x1e\n\x16service_key_secret_key\x18\x01 \x01(\t\"I\n\'PagerdutyEventsV2SystemSecretDescriptor\x12\x1e\n\x16routing_key_secret_key\x18\x01 \x01(\t\"j\n\x17PagerdutyValidationSpec\x12O\n\x15pagerduty_auth_config\x18\x01 \x01(\x0b\x32\x30.qwak.integration.management.PagerdutyAuthConfig\"\x1d\n\x1bPagerdutyIntegrationOptionsBH\n&com.qwak.ai.management.integration.apiP\x01Z\x1cqwak/integration;integrationb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.integration.pagerduty_integration_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n&com.qwak.ai.management.integration.apiP\001Z\034qwak/integration;integration'
  _PAGERDUTYINTEGRATION.fields_by_name['encrypted_pagerduty_auth_config']._options = None
  _PAGERDUTYINTEGRATION.fields_by_name['encrypted_pagerduty_auth_config']._serialized_options = b'\030\001'
  _globals['_PAGERDUTYINTEGRATION']._serialized_start=78
  _globals['_PAGERDUTYINTEGRATION']._serialized_end=322
  _globals['_PAGERDUTYINTEGRATIONSPEC']._serialized_start=324
  _globals['_PAGERDUTYINTEGRATIONSPEC']._serialized_end=448
  _globals['_PAGERDUTYAUTHCONFIG']._serialized_start=451
  _globals['_PAGERDUTYAUTHCONFIG']._serialized_end=662
  _globals['_PAGERDUTYEVENTSV1AUTHCONFIG']._serialized_start=664
  _globals['_PAGERDUTYEVENTSV1AUTHCONFIG']._serialized_end=714
  _globals['_PAGERDUTYEVENTSV2AUTHCONFIG']._serialized_start=716
  _globals['_PAGERDUTYEVENTSV2AUTHCONFIG']._serialized_end=766
  _globals['_PAGERDUTYSYSTEMSECRETDESCRIPTOR']._serialized_start=769
  _globals['_PAGERDUTYSYSTEMSECRETDESCRIPTOR']._serialized_end=1073
  _globals['_PAGERDUTYEVENTSV1SYSTEMSECRETDESCRIPTOR']._serialized_start=1075
  _globals['_PAGERDUTYEVENTSV1SYSTEMSECRETDESCRIPTOR']._serialized_end=1148
  _globals['_PAGERDUTYEVENTSV2SYSTEMSECRETDESCRIPTOR']._serialized_start=1150
  _globals['_PAGERDUTYEVENTSV2SYSTEMSECRETDESCRIPTOR']._serialized_end=1223
  _globals['_PAGERDUTYVALIDATIONSPEC']._serialized_start=1225
  _globals['_PAGERDUTYVALIDATIONSPEC']._serialized_end=1331
  _globals['_PAGERDUTYINTEGRATIONOPTIONS']._serialized_start=1333
  _globals['_PAGERDUTYINTEGRATIONOPTIONS']._serialized_end=1362
# @@protoc_insertion_point(module_scope)



from typing import Optional, List
from urllib.parse import urlparse


def join_url(base_uri: str, *parts: str) -> str:
    base_uri = base_uri.rstrip("/")

    cleaned_parts: List[str] = [
        part.strip("/") for part in parts if part is not None and part.strip("/")
    ]
    uri_parts: List[str] = [base_uri, *cleaned_parts]

    return "/".join(uri_parts)


def assemble_artifact_url(uri: Optional[str]) -> str:
    if uri is None:
        raise Exception("Artifactory URI is required")

    parsed_url = urlparse(uri)
    if parsed_url.scheme not in ["http", "https"]:
        raise Exception(
            f"Not a valid Artifactory URI: {uri}. "
            f"Artifactory URI example: `https://frogger.jfrog.io/artifactory/ml-local`"
        )

    return f"{parsed_url.scheme}://{parsed_url.netloc}/artifactory"



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/user_application/common/v0/resources.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/qwak/user_application/common/v0/resources.proto\x12\x1fqwak.user_application.common.v0\"u\n\x0c\x43puResources\x12\x0b\n\x03\x63pu\x18\x01 \x01(\x02\x12\x15\n\rmemory_amount\x18\x02 \x01(\x05\x12\x41\n\x0cmemory_units\x18\x03 \x01(\x0e\x32+.qwak.user_application.common.v0.MemoryUnit\"^\n\x0cGpuResources\x12:\n\x08gpu_type\x18\x01 \x01(\x0e\x32(.qwak.user_application.common.v0.GpuType\x12\x12\n\ngpu_amount\x18\x02 \x01(\x05\"s\n SparkClusterResourceTemplateSpec\x12O\n\x08template\x18\x01 \x01(\x0e\x32=.qwak.user_application.common.v0.SparkClusterResourceTemplate\"\xc3\x01\n\x1aSparkResourceConfiguration\x12\x15\n\rdriver_memory\x18\x01 \x01(\t\x12\x14\n\x0c\x64river_cores\x18\x02 \x01(\x05\x12\x19\n\x11initial_executors\x18\x03 \x01(\x05\x12\x15\n\rmin_executors\x18\x04 \x01(\x05\x12\x15\n\rmax_executors\x18\x05 \x01(\x05\x12\x17\n\x0f\x65xecutor_memory\x18\x06 \x01(\t\x12\x16\n\x0e\x65xecutor_cores\x18\x07 \x01(\x05\"5\n\x1ePodComputeResourceTemplateSpec\x12\x13\n\x0btemplate_id\x18\x01 \x01(\t\"\xcb\x02\n\x13PodComputeResources\x12P\n\x11optimization_type\x18\x01 \x01(\x0e\x32\x35.qwak.user_application.common.v0.NodeOptimizationType\x12\x44\n\rcpu_resources\x18\x02 \x01(\x0b\x32-.qwak.user_application.common.v0.CpuResources\x12\x44\n\rgpu_resources\x18\x03 \x01(\x0b\x32-.qwak.user_application.common.v0.GpuResources\x12V\n\rtemplate_spec\x18\x04 \x01(\x0b\x32?.qwak.user_application.common.v0.PodComputeResourceTemplateSpec\"t\n\x15SparkComputeResources\x12[\n\x16resource_configuration\x18\x01 \x01(\x0b\x32;.qwak.user_application.common.v0.SparkResourceConfiguration\"\xe5\x01\n\x1b\x43lientSparkComputeResources\x12Z\n\rtemplate_spec\x18\x01 \x01(\x0b\x32\x41.qwak.user_application.common.v0.SparkClusterResourceTemplateSpecH\x00\x12]\n\x16resource_configuration\x18\x02 \x01(\x0b\x32;.qwak.user_application.common.v0.SparkResourceConfigurationH\x00\x42\x0b\n\tresources\"\xe9\x02\n\x19\x43lientPodComputeResources\x12U\n\x16node_optimization_type\x18\x01 \x01(\x0e\x32\x35.qwak.user_application.common.v0.NodeOptimizationType\x12X\n\rtemplate_spec\x18\x02 \x01(\x0b\x32?.qwak.user_application.common.v0.PodComputeResourceTemplateSpecH\x00\x12\x46\n\rcpu_resources\x18\x03 \x01(\x0b\x32-.qwak.user_application.common.v0.CpuResourcesH\x00\x12\x46\n\rgpu_resources\x18\x04 \x01(\x0b\x32-.qwak.user_application.common.v0.GpuResourcesH\x00\x42\x0b\n\tresources*7\n\nMemoryUnit\x12\x17\n\x13INVALID_MEMORY_UNIT\x10\x00\x12\x07\n\x03MIB\x10\x01\x12\x07\n\x03GIB\x10\x02*\x95\x02\n\x07GpuType\x12\x14\n\x10INVALID_GPU_TYPE\x10\x00\x12\x0e\n\nNVIDIA_K80\x10\x01\x12\x0f\n\x0bNVIDIA_V100\x10\x02\x12\x0f\n\x0bNVIDIA_A100\x10\x03\x12\r\n\tNVIDIA_T4\x10\x04\x12\x0f\n\x0bNVIDIA_A10G\x10\x05\x12\r\n\tNVIDIA_L4\x10\x06\x12\x14\n\x10NVIDIA_T4_1_4_15\x10\x07\x12\x14\n\x10NVIDIA_T4_1_8_30\x10\x08\x12\x15\n\x11NVIDIA_T4_1_16_60\x10\t\x12\x1e\n\x1aNVIDIA_A100_80GB_8_96_1360\x10\n\x12\x16\n\x12NVIDIA_V100_1_8_52\x10\x0b\x12\x18\n\x14NVIDIA_V100_4_32_208\x10\x0c*\x88\x02\n\x1cSparkClusterResourceTemplate\x12\"\n\x1eSPARK_CLUSTER_RESOURCE_INVALID\x10\x00\x12 \n\x1cSPARK_CLUSTER_RESOURCE_SMALL\x10\x01\x12!\n\x1dSPARK_CLUSTER_RESOURCE_MEDIUM\x10\x02\x12 \n\x1cSPARK_CLUSTER_RESOURCE_LARGE\x10\x03\x12\x1d\n\x19SPARK_CLUSTER_RESOURCE_XL\x10\x04\x12\x1e\n\x1aSPARK_CLUSTER_RESOURCE_2XL\x10\x05\x12\x1e\n\x1aSPARK_CLUSTER_RESOURCE_3XL\x10\x06*\x8a\x01\n\x14NodeOptimizationType\x12\x1d\n\x19NODE_OPTIMIZATION_INVALID\x10\x00\x12\x1a\n\x16NODE_OPTIMIZATION_NONE\x10\x01\x12\x19\n\x15NODE_OPTIMIZATION_CPU\x10\x02\x12\x1c\n\x18NODE_OPTIMIZATION_MEMORY\x10\x03\x42\xc5\x01\n&com.qwak.ai.user_application.common.v0P\x01Z\x98\x01github.com/qwak-ai/qwak-platform/services/core/go/admiral/user-application-value-api/pb/qwak/user_application_value/common/v0;user_application_common_v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.user_application.common.v0.resources_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n&com.qwak.ai.user_application.common.v0P\001Z\230\001github.com/qwak-ai/qwak-platform/services/core/go/admiral/user-application-value-api/pb/qwak/user_application_value/common/v0;user_application_common_v0'
  _globals['_MEMORYUNIT']._serialized_start=1717
  _globals['_MEMORYUNIT']._serialized_end=1772
  _globals['_GPUTYPE']._serialized_start=1775
  _globals['_GPUTYPE']._serialized_end=2052
  _globals['_SPARKCLUSTERRESOURCETEMPLATE']._serialized_start=2055
  _globals['_SPARKCLUSTERRESOURCETEMPLATE']._serialized_end=2319
  _globals['_NODEOPTIMIZATIONTYPE']._serialized_start=2322
  _globals['_NODEOPTIMIZATIONTYPE']._serialized_end=2460
  _globals['_CPURESOURCES']._serialized_start=84
  _globals['_CPURESOURCES']._serialized_end=201
  _globals['_GPURESOURCES']._serialized_start=203
  _globals['_GPURESOURCES']._serialized_end=297
  _globals['_SPARKCLUSTERRESOURCETEMPLATESPEC']._serialized_start=299
  _globals['_SPARKCLUSTERRESOURCETEMPLATESPEC']._serialized_end=414
  _globals['_SPARKRESOURCECONFIGURATION']._serialized_start=417
  _globals['_SPARKRESOURCECONFIGURATION']._serialized_end=612
  _globals['_PODCOMPUTERESOURCETEMPLATESPEC']._serialized_start=614
  _globals['_PODCOMPUTERESOURCETEMPLATESPEC']._serialized_end=667
  _globals['_PODCOMPUTERESOURCES']._serialized_start=670
  _globals['_PODCOMPUTERESOURCES']._serialized_end=1001
  _globals['_SPARKCOMPUTERESOURCES']._serialized_start=1003
  _globals['_SPARKCOMPUTERESOURCES']._serialized_end=1119
  _globals['_CLIENTSPARKCOMPUTERESOURCES']._serialized_start=1122
  _globals['_CLIENTSPARKCOMPUTERESOURCES']._serialized_end=1351
  _globals['_CLIENTPODCOMPUTERESOURCES']._serialized_start=1354
  _globals['_CLIENTPODCOMPUTERESOURCES']._serialized_end=1715
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/builds/internal_builds_orchestrator_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.builds import build_pb2 as qwak_dot_builds_dot_build__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6qwak/builds/internal_builds_orchestrator_service.proto\x12\x18qwak.builds.orchestrator\x1a\x17qwak/builds/build.proto\"\x8e\x01\n\x10\x42uildInitDetails\x12=\n\nbuild_spec\x18\x01 \x01(\x0b\x32).qwak.builds.orchestrator.RemoteBuildSpec\x12;\n\tinitiator\x18\x02 \x01(\x0b\x32(.qwak.builds.orchestrator.BuildInitiator\"c\n\x19InternalBuildModelRequest\x12\x46\n\x12\x62uild_init_details\x18\x01 \x01(\x0b\x32*.qwak.builds.orchestrator.BuildInitDetails\"\x1c\n\x1aInternalBuildModelResponse2\x9c\x01\n!InternalBuildsOrchestratorService\x12w\n\nBuildModel\x12\x33.qwak.builds.orchestrator.InternalBuildModelRequest\x1a\x34.qwak.builds.orchestrator.InternalBuildModelResponseB\'\n#com.qwak.ai.builds.orchestrator.apiP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.builds.internal_builds_orchestrator_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#com.qwak.ai.builds.orchestrator.apiP\001'
  _globals['_BUILDINITDETAILS']._serialized_start=110
  _globals['_BUILDINITDETAILS']._serialized_end=252
  _globals['_INTERNALBUILDMODELREQUEST']._serialized_start=254
  _globals['_INTERNALBUILDMODELREQUEST']._serialized_end=353
  _globals['_INTERNALBUILDMODELRESPONSE']._serialized_start=355
  _globals['_INTERNALBUILDMODELRESPONSE']._serialized_end=383
  _globals['_INTERNALBUILDSORCHESTRATORSERVICE']._serialized_start=386
  _globals['_INTERNALBUILDSORCHESTRATORSERVICE']._serialized_end=542
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import qwak.administration.runtime_configuration.v0.network_config_pb2
import qwak.administration.runtime_configuration.v0.runtime_config_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _ClusterInstallationType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ClusterInstallationTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ClusterInstallationType.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    CLUSTER_INSTALLATION_TYPE_INVALID: _ClusterInstallationType.ValueType  # 0
    SELF_HOSTED_CLUSTER_INSTALLATION_TYPE: _ClusterInstallationType.ValueType  # 1
    SELF_SERVICE_CLUSTER_INSTALLATION_TYPE: _ClusterInstallationType.ValueType  # 2
    HYBRID_CLUSTER_INSTALLATION_TYPE: _ClusterInstallationType.ValueType  # 3

class ClusterInstallationType(_ClusterInstallationType, metaclass=_ClusterInstallationTypeEnumTypeWrapper): ...

CLUSTER_INSTALLATION_TYPE_INVALID: ClusterInstallationType.ValueType  # 0
SELF_HOSTED_CLUSTER_INSTALLATION_TYPE: ClusterInstallationType.ValueType  # 1
SELF_SERVICE_CLUSTER_INSTALLATION_TYPE: ClusterInstallationType.ValueType  # 2
HYBRID_CLUSTER_INSTALLATION_TYPE: ClusterInstallationType.ValueType  # 3
global___ClusterInstallationType = ClusterInstallationType

class Cluster(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CONFIGURATION_FIELD_NUMBER: builtins.int
    CLUSTER_METADATA_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Assigned cluster ID"""
    name: builtins.str
    """Cluster name"""
    @property
    def configuration(self) -> global___ClusterConfiguration:
        """Cluster configuration"""
    @property
    def cluster_metadata(self) -> global___ClusterMetadata:
        """Cluster metadata"""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        configuration: global___ClusterConfiguration | None = ...,
        cluster_metadata: global___ClusterMetadata | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cluster_metadata", b"cluster_metadata", "configuration", b"configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cluster_metadata", b"cluster_metadata", "configuration", b"configuration", "id", b"id", "name", b"name"]) -> None: ...

global___Cluster = Cluster

class ClusterMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATED_AT_FIELD_NUMBER: builtins.int
    CREATED_BY_FIELD_NUMBER: builtins.int
    LAST_MODIFIED_AT_FIELD_NUMBER: builtins.int
    LAST_MODIFIED_BY_FIELD_NUMBER: builtins.int
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """When the cluster was created"""
    created_by: builtins.str
    """User-id who created the cluster"""
    @property
    def last_modified_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """When the cluster was last modified"""
    last_modified_by: builtins.str
    """User-id who last modified the cluster"""
    def __init__(
        self,
        *,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        created_by: builtins.str = ...,
        last_modified_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        last_modified_by: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["created_at", b"created_at", "last_modified_at", b"last_modified_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["created_at", b"created_at", "created_by", b"created_by", "last_modified_at", b"last_modified_at", "last_modified_by", b"last_modified_by"]) -> None: ...

global___ClusterMetadata = ClusterMetadata

class ClusterConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SELF_HOSTED_CONFIGURATION_FIELD_NUMBER: builtins.int
    SELF_SERVICE_CONFIGURATION_FIELD_NUMBER: builtins.int
    HYBRID_CONFIGURATION_FIELD_NUMBER: builtins.int
    @property
    def self_hosted_configuration(self) -> global___SelfHostedConfiguration: ...
    @property
    def self_service_configuration(self) -> global___SelfServiceConfiguration: ...
    @property
    def hybrid_configuration(self) -> global___HybridConfiguration: ...
    def __init__(
        self,
        *,
        self_hosted_configuration: global___SelfHostedConfiguration | None = ...,
        self_service_configuration: global___SelfServiceConfiguration | None = ...,
        hybrid_configuration: global___HybridConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["hybrid_configuration", b"hybrid_configuration", "self_hosted_configuration", b"self_hosted_configuration", "self_service_configuration", b"self_service_configuration", "type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["hybrid_configuration", b"hybrid_configuration", "self_hosted_configuration", b"self_hosted_configuration", "self_service_configuration", b"self_service_configuration", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["type", b"type"]) -> typing_extensions.Literal["self_hosted_configuration", "self_service_configuration", "hybrid_configuration"] | None: ...

global___ClusterConfiguration = ClusterConfiguration

class SelfHostedConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RUNTIME_CONFIGURATION_FIELD_NUMBER: builtins.int
    @property
    def runtime_configuration(self) -> global___RuntimeConfiguration: ...
    def __init__(
        self,
        *,
        runtime_configuration: global___RuntimeConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["runtime_configuration", b"runtime_configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["runtime_configuration", b"runtime_configuration"]) -> None: ...

global___SelfHostedConfiguration = SelfHostedConfiguration

class SelfServiceConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RUNTIME_CONFIGURATION_FIELD_NUMBER: builtins.int
    @property
    def runtime_configuration(self) -> global___RuntimeConfiguration: ...
    def __init__(
        self,
        *,
        runtime_configuration: global___RuntimeConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["runtime_configuration", b"runtime_configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["runtime_configuration", b"runtime_configuration"]) -> None: ...

global___SelfServiceConfiguration = SelfServiceConfiguration

class HybridConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RUNTIME_CONFIGURATION_FIELD_NUMBER: builtins.int
    @property
    def runtime_configuration(self) -> global___RuntimeConfiguration: ...
    def __init__(
        self,
        *,
        runtime_configuration: global___RuntimeConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["runtime_configuration", b"runtime_configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["runtime_configuration", b"runtime_configuration"]) -> None: ...

global___HybridConfiguration = HybridConfiguration

class RuntimeConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RUNTIME_CONFIGURATION_FIELD_NUMBER: builtins.int
    NETWORK_CONFIGURATION_FIELD_NUMBER: builtins.int
    @property
    def runtime_configuration(self) -> qwak.administration.runtime_configuration.v0.runtime_config_pb2.RuntimeConfiguration: ...
    @property
    def network_configuration(self) -> qwak.administration.runtime_configuration.v0.network_config_pb2.ClusterNetworkConfiguration: ...
    def __init__(
        self,
        *,
        runtime_configuration: qwak.administration.runtime_configuration.v0.runtime_config_pb2.RuntimeConfiguration | None = ...,
        network_configuration: qwak.administration.runtime_configuration.v0.network_config_pb2.ClusterNetworkConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["network_configuration", b"network_configuration", "runtime_configuration", b"runtime_configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["network_configuration", b"network_configuration", "runtime_configuration", b"runtime_configuration"]) -> None: ...

global___RuntimeConfiguration = RuntimeConfiguration

class ClusterSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    CONFIGURATION_SPEC_FIELD_NUMBER: builtins.int
    display_name: builtins.str
    """display name"""
    @property
    def configuration_spec(self) -> global___ClusterConfigurationSpec:
        """Configuration for the cluster"""
    def __init__(
        self,
        *,
        display_name: builtins.str = ...,
        configuration_spec: global___ClusterConfigurationSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["configuration_spec", b"configuration_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["configuration_spec", b"configuration_spec", "display_name", b"display_name"]) -> None: ...

global___ClusterSpec = ClusterSpec

class ClusterConfigurationSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SELF_HOSTED_CONFIGURATION_FIELD_NUMBER: builtins.int
    SELF_SERVICE_CONFIGURATION_FIELD_NUMBER: builtins.int
    HYBRID_CONFIGURATION_FIELD_NUMBER: builtins.int
    @property
    def self_hosted_configuration(self) -> global___SelfHostedConfigurationSpec: ...
    @property
    def self_service_configuration(self) -> global___SelfServiceConfigurationSpec: ...
    @property
    def hybrid_configuration(self) -> global___HybridConfigurationSpec: ...
    def __init__(
        self,
        *,
        self_hosted_configuration: global___SelfHostedConfigurationSpec | None = ...,
        self_service_configuration: global___SelfServiceConfigurationSpec | None = ...,
        hybrid_configuration: global___HybridConfigurationSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["hybrid_configuration", b"hybrid_configuration", "self_hosted_configuration", b"self_hosted_configuration", "self_service_configuration", b"self_service_configuration", "type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["hybrid_configuration", b"hybrid_configuration", "self_hosted_configuration", b"self_hosted_configuration", "self_service_configuration", b"self_service_configuration", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["type", b"type"]) -> typing_extensions.Literal["self_hosted_configuration", "self_service_configuration", "hybrid_configuration"] | None: ...

global___ClusterConfigurationSpec = ClusterConfigurationSpec

class SelfHostedConfigurationSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RUNTIME_CONFIGURATION_FIELD_NUMBER: builtins.int
    @property
    def runtime_configuration(self) -> global___RuntimeConfigurationSpec: ...
    def __init__(
        self,
        *,
        runtime_configuration: global___RuntimeConfigurationSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["runtime_configuration", b"runtime_configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["runtime_configuration", b"runtime_configuration"]) -> None: ...

global___SelfHostedConfigurationSpec = SelfHostedConfigurationSpec

class SelfServiceConfigurationSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RUNTIME_CONFIGURATION_FIELD_NUMBER: builtins.int
    @property
    def runtime_configuration(self) -> global___RuntimeConfigurationSpec: ...
    def __init__(
        self,
        *,
        runtime_configuration: global___RuntimeConfigurationSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["runtime_configuration", b"runtime_configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["runtime_configuration", b"runtime_configuration"]) -> None: ...

global___SelfServiceConfigurationSpec = SelfServiceConfigurationSpec

class HybridConfigurationSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RUNTIME_CONFIGURATION_FIELD_NUMBER: builtins.int
    @property
    def runtime_configuration(self) -> global___RuntimeConfigurationSpec: ...
    def __init__(
        self,
        *,
        runtime_configuration: global___RuntimeConfigurationSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["runtime_configuration", b"runtime_configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["runtime_configuration", b"runtime_configuration"]) -> None: ...

global___HybridConfigurationSpec = HybridConfigurationSpec

class RuntimeConfigurationSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RUNTIME_CONFIGURATION_FIELD_NUMBER: builtins.int
    NETWORK_CONFIGURATION_FIELD_NUMBER: builtins.int
    @property
    def runtime_configuration(self) -> qwak.administration.runtime_configuration.v0.runtime_config_pb2.RuntimeConfiguration: ...
    @property
    def network_configuration(self) -> qwak.administration.runtime_configuration.v0.network_config_pb2.ClusterNetworkConfiguration: ...
    def __init__(
        self,
        *,
        runtime_configuration: qwak.administration.runtime_configuration.v0.runtime_config_pb2.RuntimeConfiguration | None = ...,
        network_configuration: qwak.administration.runtime_configuration.v0.network_config_pb2.ClusterNetworkConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["network_configuration", b"network_configuration", "runtime_configuration", b"runtime_configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["network_configuration", b"network_configuration", "runtime_configuration", b"runtime_configuration"]) -> None: ...

global___RuntimeConfigurationSpec = RuntimeConfigurationSpec

class ClusterState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALID_FIELD_NUMBER: builtins.int
    @property
    def valid(self) -> global___ClusterValid:
        """TBD: updating, deleting etc states"""
    def __init__(
        self,
        *,
        valid: global___ClusterValid | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["state", b"state", "valid", b"valid"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["state", b"state", "valid", b"valid"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["state", b"state"]) -> typing_extensions.Literal["valid"] | None: ...

global___ClusterState = ClusterState

class ClusterValid(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_FIELD_NUMBER: builtins.int
    @property
    def cluster(self) -> global___Cluster: ...
    def __init__(
        self,
        *,
        cluster: global___Cluster | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cluster", b"cluster"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cluster", b"cluster"]) -> None: ...

global___ClusterValid = ClusterValid

class ClusterBrief(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INSTALLATION_TYPE_FIELD_NUMBER: builtins.int
    installation_type: global___ClusterInstallationType.ValueType
    def __init__(
        self,
        *,
        installation_type: global___ClusterInstallationType.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["installation_type", b"installation_type"]) -> None: ...

global___ClusterBrief = ClusterBrief



from concurrent import futures
from typing import Any, Generator, List, Tuple

import grpc
import pytest

from _qwak_proto.qwak.administration.v0.authentication.authentication_service_pb2_grpc import (
    add_AuthenticationServiceServicer_to_server,
)
from _qwak_proto.qwak.admiral.secret.v0.system_secret_service_pb2_grpc import (
    add_SystemSecretServiceServicer_to_server,
)
from _qwak_proto.qwak.admiral.user_application_instance.v0.user_application_instance_service_pb2_grpc import (
    add_UserApplicationInstanceServiceServicer_to_server,
)
from _qwak_proto.qwak.analytics.analytics_service_pb2_grpc import (
    add_AnalyticsQueryServiceServicer_to_server,
)
from _qwak_proto.qwak.audience.v1.audience_api_pb2_grpc import (
    add_AudienceAPIServicer_to_server,
)
from _qwak_proto.qwak.auto_scaling.v1.auto_scaling_service_pb2_grpc import (
    add_AutoScalingServiceServicer_to_server,
)
from _qwak_proto.qwak.automation.v1.automation_management_service_pb2_grpc import (
    add_AutomationManagementServiceServicer_to_server,
)
from _qwak_proto.qwak.batch_job.v1.batch_job_service_pb2_grpc import (
    add_BatchJobManagementServiceServicer_to_server,
)
from _qwak_proto.qwak.build.v1.build_api_pb2_grpc import add_BuildAPIServicer_to_server
from _qwak_proto.qwak.build_settings.build_settings_api_pb2_grpc import (
    add_BuildSettingsApiServicer_to_server,
)
from _qwak_proto.qwak.builds.builds_orchestrator_service_pb2_grpc import (
    add_BuildsOrchestratorServiceServicer_to_server,
)
from _qwak_proto.qwak.builds.internal_builds_orchestrator_service_pb2_grpc import (
    add_InternalBuildsOrchestratorServiceServicer_to_server,
)
from _qwak_proto.qwak.data_versioning.data_versioning_service_pb2_grpc import (
    add_DataVersioningManagementServiceServicer_to_server,
)
from _qwak_proto.qwak.deployment.alert_service_pb2_grpc import (
    add_AlertManagementServiceServicer_to_server,
)
from _qwak_proto.qwak.deployment.deployment_service_pb2_grpc import (
    add_DeploymentManagementServiceServicer_to_server,
)
from _qwak_proto.qwak.ecosystem.v0.ecosystem_runtime_service_pb2_grpc import (
    add_QwakEcosystemRuntimeServicer_to_server,
)
from _qwak_proto.qwak.execution.v1.execution_service_pb2_grpc import (
    add_FeatureStoreExecutionServiceServicer_to_server,
)
from _qwak_proto.qwak.feature_store.entities.entity_service_pb2_grpc import (
    add_EntityServiceServicer_to_server,
)
from _qwak_proto.qwak.feature_store.features.feature_set_service_pb2_grpc import (
    add_FeatureSetServiceServicer_to_server,
)
from _qwak_proto.qwak.feature_store.jobs.v1.job_service_pb2_grpc import (
    add_JobServiceServicer_to_server,
)
from _qwak_proto.qwak.feature_store.sources.data_source_service_pb2_grpc import (
    add_DataSourceServiceServicer_to_server,
)
from _qwak_proto.qwak.features_operator.v3.features_operator_async_service_pb2_grpc import (
    add_FeaturesOperatorAsyncServiceServicer_to_server,
)
from _qwak_proto.qwak.file_versioning.file_versioning_service_pb2_grpc import (
    add_FileVersioningManagementServiceServicer_to_server,
)
from _qwak_proto.qwak.instance_template.instance_template_service_pb2_grpc import (
    add_InstanceTemplateManagementServiceServicer_to_server,
)
from _qwak_proto.qwak.integration.integration_service_pb2_grpc import (
    add_IntegrationManagementServiceServicer_to_server,
)
from _qwak_proto.qwak.kube_deployment_captain.kube_deployment_captain_service_pb2_grpc import (
    add_KubeDeploymentCaptainServicer_to_server,
)
from _qwak_proto.qwak.logging.log_reader_service_pb2_grpc import (
    add_LogReaderServiceServicer_to_server,
)
from _qwak_proto.qwak.models.models_pb2_grpc import (
    add_ModelsManagementServiceServicer_to_server,
)
from _qwak_proto.qwak.monitoring.v0.alerting_channel_management_service_pb2_grpc import (
    add_AlertingChannelManagementServiceServicer_to_server,
)
from _qwak_proto.qwak.offline.serving.v1.offline_serving_async_service_pb2_grpc import (
    add_FeatureStoreOfflineServingAsyncServiceServicer_to_server,
)
from _qwak_proto.qwak.projects.projects_pb2_grpc import (
    add_ProjectsManagementServiceServicer_to_server,
)
from _qwak_proto.qwak.prompt.v1.prompt.prompt_manager_service_pb2_grpc import (
    add_PromptManagerServiceServicer_to_server,
)
from _qwak_proto.qwak.secret_service.secret_service_pb2_grpc import (
    add_SecretServiceServicer_to_server,
)
from _qwak_proto.qwak.self_service.user.v1.user_service_pb2_grpc import (
    add_UserServiceServicer_to_server,
)
from _qwak_proto.qwak.service_discovery.service_discovery_location_service_pb2_grpc import (
    add_LocationDiscoveryServiceServicer_to_server,
)
from _qwak_proto.qwak.vectors.v1.collection.collection_service_pb2_grpc import (
    add_VectorCollectionServiceServicer_to_server,
)
from _qwak_proto.qwak.vectors.v1.vector_service_pb2_grpc import (
    add_VectorServiceServicer_to_server,
)
from _qwak_proto.qwak.workspace.workspace_service_pb2_grpc import (
    add_WorkspaceManagementServiceServicer_to_server,
)
from qwak.inner.di_configuration import QwakContainer
from qwak_services_mock.mocks.alert_manager_service_api import (
    AlertManagerServiceApiMock,
)
from qwak_services_mock.mocks.alert_registry_service_api import (
    AlertsRegistryServiceApiMock,
)
from qwak_services_mock.mocks.analytics_api import AnalyticsApiMock
from qwak_services_mock.mocks.audience_service_api import AudienceServiceApiMock
from qwak_services_mock.mocks.authentication_service import AuthenticationServiceMock
from qwak_services_mock.mocks.automation_management_service import (
    AutomationManagementServiceMock,
)
from qwak_services_mock.mocks.autoscaling_service_api import AutoscalingServiceApiMock
from qwak_services_mock.mocks.batch_job_manager_service import BatchJobManagerService
from qwak_services_mock.mocks.build_orchestrator_build_api import (
    BuildOrchestratorBuildApiMock,
)
from qwak_services_mock.mocks.build_orchestrator_build_settings_api import (
    BuildOrchestratorBuildSettingsApiMock,
)
from qwak_services_mock.mocks.build_orchestrator_service_api import (
    BuildOrchestratorServiceApiMock,
)
from qwak_services_mock.mocks.data_versioning_service import DataVersioningServiceMock
from qwak_services_mock.mocks.deployment_management_service import (
    DeploymentManagementServiceMock,
)
from qwak_services_mock.mocks.ecosystem_service_api import EcoSystemServiceMock
from qwak_services_mock.mocks.execution_management_service import (
    ExecutionManagementServiceMock,
)
from qwak_services_mock.mocks.feature_store_data_sources_manager_api import (
    DataSourceServiceMock,
)
from qwak_services_mock.mocks.feature_store_entities_manager_api import (
    EntityServiceMock,
)
from qwak_services_mock.mocks.feature_store_feature_set_manager_api import (
    FeatureSetServiceMock,
)
from qwak_services_mock.mocks.features_operator_v3_service import (
    FeaturesOperatorV3ServiceMock,
)
from qwak_services_mock.mocks.file_versioning_service import FileVersioningServiceMock
from qwak_services_mock.mocks.fs_offline_serving_service import (
    FsOfflineServingServiceMock,
)
from qwak_services_mock.mocks.instance_template_management_service import (
    InstanceTemplateManagementServiceMock,
)
from qwak_services_mock.mocks.integration_management_service import (
    IntegrationManagementServiceMock,
)
from qwak_services_mock.mocks.internal_build_orchestrator_service import (
    InternalBuildOrchestratorServiceMock,
)
from qwak_services_mock.mocks.job_registry_service_api import JobRegistryServiceApiMock
from qwak_services_mock.mocks.kube_captain_service_api import KubeCaptainServiceApiMock
from qwak_services_mock.mocks.location_discovery_service_api import (
    LocationDiscoveryServiceApiMock,
)
from qwak_services_mock.mocks.logging_service import LoggingServiceApiMock
from qwak_services_mock.mocks.model_management_service import (
    ModelsManagementServiceMock,
)
from qwak_services_mock.mocks.project_manager_service import ProjectManagerServiceMock
from qwak_services_mock.mocks.prompt_manager_service import PromptManagerServiceMock
from qwak_services_mock.mocks.qwak_mocks import QwakMocks
from qwak_services_mock.mocks.secret_service import SecretServiceMock
from qwak_services_mock.mocks.self_service_user_service import (
    SelfServiceUserServiceMock,
)
from qwak_services_mock.mocks.system_secret_service import SystemSecretServiceMock
from qwak_services_mock.mocks.user_application_instance_service_api import (
    UserApplicationInstanceServiceApiMock,
)
from qwak_services_mock.mocks.vector_serving_api import VectorServingServiceMock
from qwak_services_mock.mocks.vectors_management_api import (
    VectorCollectionManagementServiceMock,
)
from qwak_services_mock.mocks.workspace_manager_service_mock import (
    WorkspaceManagerServiceMock,
)
from qwak_services_mock.utils.service_utils import find_free_port


def qwak_container():
    free_port = find_free_port()
    container = QwakContainer(
        config={
            "grpc": {
                "core": {
                    "address": f"localhost:{free_port}",
                    "enable_ssl": False,
                },
                "builds": {
                    "internal_address": f"localhost:{free_port}",
                    "enable_ssl": False,
                },
                "authentication": {
                    "enable_ssl": False,
                },
            },
        },
    )
    from qwak.clients import (
        alert_management,
        alerts_registry,
        analytics,
        audience,
        automation_management,
        autoscaling,
        batch_job_management,
        build_orchestrator,
        data_versioning,
        deployment,
        feature_store,
        file_versioning,
        instance_template,
        kube_deployment_captain,
        location_discovery,
        logging_client,
        model_management,
        project,
        secret_service,
        user_application_instance,
        vector_store,
        workspace_manager,
    )
    from qwak.clients.administration import authentication, eco_system, self_service
    from qwak.clients.integration_management import integration_manager_client
    from qwak.clients.prompt_manager import prompt_manager_client
    from qwak.clients.system_secret import system_secret_client
    from qwak.vector_store.utils import upsert_utils

    container.wire(
        packages=[
            authentication,
            alert_management,
            audience,
            automation_management,
            autoscaling,
            analytics,
            batch_job_management,
            build_orchestrator,
            data_versioning,
            deployment,
            instance_template,
            feature_store,
            file_versioning,
            kube_deployment_captain,
            logging_client,
            model_management,
            project,
            self_service,
            eco_system,
            user_application_instance,
            secret_service,
            alerts_registry,
            workspace_manager,
            vector_store,
            upsert_utils,
            integration_manager_client,
            system_secret_client,
            prompt_manager_client,
            location_discovery,
        ]
    )

    return free_port


def qwak_service_mock_creator(server, mocks: List[Tuple[Any, Any, Any]]) -> QwakMocks:
    activated_mocks = {
        mock[0]: mock[1]() if callable(mock[1]) else mock[1] for mock in mocks
    }
    qwak_mocks = QwakMocks(**activated_mocks)
    for property_name, value, servicer in mocks:
        if servicer:
            servicer(getattr(qwak_mocks, property_name), server)

    return qwak_mocks


def attach_servicers(free_port, server):
    qwak_mocks = qwak_service_mock_creator(
        server,
        [
            (
                "integration_management_service",
                IntegrationManagementServiceMock,
                add_IntegrationManagementServiceServicer_to_server,
            ),
            (
                "system_secret_service",
                SystemSecretServiceMock,
                add_SystemSecretServiceServicer_to_server,
            ),
            (
                "autoscaling_service_mock",
                AutoscalingServiceApiMock,
                add_AutoScalingServiceServicer_to_server,
            ),
            (
                "build_orchestrator_build_api",
                BuildOrchestratorBuildApiMock,
                add_BuildAPIServicer_to_server,
            ),
            (
                "build_orchestrator_service_api",
                BuildOrchestratorServiceApiMock,
                add_BuildsOrchestratorServiceServicer_to_server,
            ),
            (
                "build_orchestrator_build_settings_api",
                BuildOrchestratorBuildSettingsApiMock,
                add_BuildSettingsApiServicer_to_server,
            ),
            (
                "internal_build_orchestrator_service",
                InternalBuildOrchestratorServiceMock,
                add_InternalBuildsOrchestratorServiceServicer_to_server,
            ),
            (
                "alert_manager_service_mock",
                AlertManagerServiceApiMock,
                add_AlertManagementServiceServicer_to_server,
            ),
            (
                "automation_management_service_mock",
                AutomationManagementServiceMock,
                add_AutomationManagementServiceServicer_to_server,
            ),
            (
                "ecosystem_client_mock",
                EcoSystemServiceMock,
                add_QwakEcosystemRuntimeServicer_to_server,
            ),
            (
                "job_registry_service_mock",
                JobRegistryServiceApiMock,
                add_JobServiceServicer_to_server,
            ),
            (
                "project_manager_service_mock",
                ProjectManagerServiceMock,
                add_ProjectsManagementServiceServicer_to_server,
            ),
            (
                "kube_captain_service_mock",
                KubeCaptainServiceApiMock,
                add_KubeDeploymentCaptainServicer_to_server,
            ),
            (
                "file_versioning_service_mock",
                FileVersioningServiceMock,
                add_FileVersioningManagementServiceServicer_to_server,
            ),
            (
                "data_versioning_service_mock",
                DataVersioningServiceMock,
                add_DataVersioningManagementServiceServicer_to_server,
            ),
            (
                "model_management_service_mock",
                ModelsManagementServiceMock,
                add_ModelsManagementServiceServicer_to_server,
            ),
            (
                "logging_service_mock",
                LoggingServiceApiMock,
                add_LogReaderServiceServicer_to_server,
            ),
            (
                "audience_api_mock",
                AudienceServiceApiMock,
                add_AudienceAPIServicer_to_server,
            ),
            (
                "self_service_user_service_mock",
                SelfServiceUserServiceMock,
                add_UserServiceServicer_to_server,
            ),
            (
                "analytics_api_mock",
                AnalyticsApiMock,
                add_AnalyticsQueryServiceServicer_to_server,
            ),
            (
                "deployment_management_service_mock",
                DeploymentManagementServiceMock,
                add_DeploymentManagementServiceServicer_to_server,
            ),
            (
                "batch_job_manager_service",
                BatchJobManagerService,
                add_BatchJobManagementServiceServicer_to_server,
            ),
            (
                "user_application_instance_service_mock",
                UserApplicationInstanceServiceApiMock,
                add_UserApplicationInstanceServiceServicer_to_server,
            ),
            (
                "secret_service_mock",
                SecretServiceMock,
                add_SecretServiceServicer_to_server,
            ),
            (
                "authentication_service_mock",
                AuthenticationServiceMock,
                add_AuthenticationServiceServicer_to_server,
            ),
            (
                "fs_entities_service",
                EntityServiceMock,
                add_EntityServiceServicer_to_server,
            ),
            (
                "fs_feature_sets_service",
                FeatureSetServiceMock,
                add_FeatureSetServiceServicer_to_server,
            ),
            (
                "fs_data_sources_service",
                DataSourceServiceMock,
                add_DataSourceServiceServicer_to_server,
            ),
            (
                "features_operator_service",
                FeaturesOperatorV3ServiceMock,
                add_FeaturesOperatorAsyncServiceServicer_to_server,
            ),
            (
                "fs_offline_serving_service",
                FsOfflineServingServiceMock,
                add_FeatureStoreOfflineServingAsyncServiceServicer_to_server,
            ),
            (
                "instance_templates_service",
                InstanceTemplateManagementServiceMock,
                add_InstanceTemplateManagementServiceServicer_to_server,
            ),
            (
                "alerts_registry_service",
                AlertsRegistryServiceApiMock,
                add_AlertingChannelManagementServiceServicer_to_server,
            ),
            (
                "workspace_manager_service",
                WorkspaceManagerServiceMock,
                add_WorkspaceManagementServiceServicer_to_server,
            ),
            (
                "vector_serving_service",
                VectorServingServiceMock,
                add_VectorServiceServicer_to_server,
            ),
            (
                "vector_collection_service",
                VectorCollectionManagementServiceMock,
                add_VectorCollectionServiceServicer_to_server,
            ),
            (
                "execution_management_service",
                ExecutionManagementServiceMock,
                add_FeatureStoreExecutionServiceServicer_to_server,
            ),
            (
                "prompt_manager_service",
                PromptManagerServiceMock,
                add_PromptManagerServiceServicer_to_server,
            ),
            (
                "location_discovery_service",
                LocationDiscoveryServiceApiMock,
                add_LocationDiscoveryServiceServicer_to_server,
            ),
            ("port", free_port, None),
        ],
    )
    return qwak_mocks


@pytest.fixture
def qwak_services_mock() -> Generator[QwakMocks, None, None]:
    free_port = qwak_container()

    server = grpc.server(futures.ThreadPoolExecutor(max_workers=10))
    qwak_mocks = attach_servicers(free_port, server)

    server.add_insecure_port(f"[::]:{free_port}")
    server.start()

    yield qwak_mocks

    server.stop(0)



import logging.config
import os
import sys

log_level = (
    "DEBUG"
    if os.getenv("JFML_DEBUG", "false").casefold() == "true".casefold()
    else "INFO"
)
log_file = f'{os.path.expanduser("~")}/.frogml/frogml-log-history.log'
os.makedirs(os.path.dirname(log_file), exist_ok=True)

DEFAULT_LOGGING = {
    "version": 1,
    "formatters": {
        "standard": {
            "format": "%(asctime)s - %(levelname)s - %(name)s.%(module)s.%(funcName)s:%(lineno)d - %(message)s"
        },
    },
    "handlers": {
        "console": {
            "class": "logging.StreamHandler",
            "formatter": "standard",
            "stream": sys.stdout,
        },
        "file": {
            "class": "logging.FileHandler",
            "formatter": "standard",
            "filename": log_file,
        },
    },
    "loggers": {
        __name__: {
            "level": log_level,
            "handlers": ["console", "file"],
            "propagate": False,
        },
    },
}

if os.getenv("IS_LOGGER_SHADED") is not None:
    logger = logging.getLogger(__name__)
else:
    logging.config.dictConfig(DEFAULT_LOGGING)
    logger = logging.getLogger(__name__)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/kube_deployment_captain/batch_job.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,qwak/kube_deployment_captain/batch_job.proto\x12\x1cqwak.kube.deployment.captain\x1a\x1egoogle/protobuf/wrappers.proto\"\xd2\x03\n\x1cListInferenceJobFilesRequest\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\x12\x16\n\x0e\x64irectory_path\x18\x02 \x01(\t\x12\x18\n\x0ctoken_secret\x18\x03 \x01(\tB\x02\x18\x01\x12\x19\n\rsecret_secret\x18\x04 \x01(\tB\x02\x18\x01\x12\x1a\n\x12secret_service_url\x18\x05 \x01(\t\x12\x14\n\x08role_arn\x18\x06 \x01(\tB\x02\x18\x01\x12G\n\x0f\x61ws_credentials\x18\x07 \x01(\x0b\x32,.qwak.kube.deployment.captain.AwsCredentialsH\x00\x12G\n\x0fgcp_credentials\x18\x08 \x01(\x0b\x32,.qwak.kube.deployment.captain.GcpCredentialsH\x00\x12P\n\x14grouped_task_details\x18\t \x01(\x0b\x32\x30.qwak.kube.deployment.captain.GroupedTaskDetailsH\x01\x12\x16\n\x0e\x65nvironment_id\x18\n \x01(\tB\x1a\n\x18\x63loud_client_credentialsB\x0b\n\ttask_flow\"c\n\x12GroupedTaskDetails\x12\x17\n\x0f\x63oncurrentTasks\x18\x01 \x01(\x05\x12\x18\n\x10\x64\x65stination_path\x18\x02 \x01(\t\x12\x1a\n\x12\x64\x65stination_bucket\x18\x03 \x01(\t\"\xb4\x02\n)CleanStorageObjectFromCloudStorageRequest\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\x12\x15\n\robject_prefix\x18\x02 \x03(\t\x12\x1a\n\x12secret_service_url\x18\x03 \x01(\t\x12G\n\x0f\x61ws_credentials\x18\x04 \x01(\x0b\x32,.qwak.kube.deployment.captain.AwsCredentialsH\x00\x12G\n\x0fgcp_credentials\x18\x05 \x01(\x0b\x32,.qwak.kube.deployment.captain.GcpCredentialsH\x00\x12\x16\n\x0e\x65nvironment_id\x18\x06 \x01(\tB\x1a\n\x18\x63loud_client_credentials\"O\n\x0e\x41wsCredentials\x12\x10\n\x08role_arn\x18\x01 \x01(\t\x12\x14\n\x0ctoken_secret\x18\x02 \x01(\t\x12\x15\n\rsecret_secret\x18\x04 \x01(\t\"9\n\x0eGcpCredentials\x12\'\n\x1fservice_account_json_key_secret\x18\x01 \x01(\t\"\xa6\x01\n\x1dListInferenceJobFilesResponse\x12\x12\n\nfile_names\x18\x01 \x03(\t\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x16\n\x0e\x66\x61ilure_reason\x18\x03 \x01(\t\x12H\n\x11list_file_details\x18\x04 \x03(\x0b\x32-.qwak.kube.deployment.captain.ListFileDetails\"W\n\x0fListFileDetails\x12\x15\n\ris_point_file\x18\x01 \x01(\x08\x12\x17\n\x0fpoint_file_path\x18\x02 \x01(\t\x12\x14\n\x0cobject_paths\x18\x03 \x03(\t\"\xf0\x01\n\"CreateInferenceTaskExecutorRequest\x12\x63\n\x1btask_executor_configuration\x18\x01 \x01(\x0b\x32>.qwak.kube.deployment.captain.TaskExecutorConfigurationMessage\x12\x65\n\x1cinference_task_configuration\x18\x02 \x01(\x0b\x32?.qwak.kube.deployment.captain.InferenceTaskConfigurationMessage\"\x89\x01\n\x1aPrepareInferenceJobRequest\x12k\n#inference_job_configuration_message\x18\x01 \x01(\x0b\x32>.qwak.kube.deployment.captain.InferenceJobConfigurationMessage\"F\n\x1bPrepareInferenceJobResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x16\n\x0e\x66\x61ilure_reason\x18\x02 \x01(\t\"\xcd\x04\n TaskExecutorConfigurationMessage\x12\x18\n\x10inference_job_id\x18\x01 \x01(\t\x12\x19\n\x11inference_task_id\x18\x02 \x01(\t\x12G\n\x10model_identifier\x18\x05 \x01(\x0b\x32-.qwak.kube.deployment.captain.ModelIdentifier\x12\x11\n\timage_url\x18\x06 \x01(\t\x12\x15\n\rbackoff_limit\x18\x07 \x01(\x05\x12\x0f\n\x03\x63pu\x18\x08 \x01(\x02\x42\x02\x18\x01\x12\x19\n\rmemory_amount\x18\t \x01(\x05\x42\x02\x18\x01\x12\x45\n\x0cmemory_units\x18\n \x01(\x0e\x32+.qwak.kube.deployment.captain.MemoryUnitApiB\x02\x18\x01\x12\x16\n\x0e\x65nvironment_id\x18\x0b \x01(\t\x12\x1b\n\x13\x63ustom_iam_role_arn\x18\x0c \x01(\t\x12\x41\n\x08job_size\x18\r \x01(\x0b\x32/.qwak.kube.deployment.captain.BatchJobResources\x12\x17\n\x0fpurchase_option\x18\x0e \x01(\t\x12\x19\n\x11image_pull_secret\x18\x0f \x01(\t\x12%\n\x1d\x63ustom_service_account_secret\x18\x10 \x01(\t\x12#\n\x1bjfrog_token_api_secret_name\x18\x11 \x01(\t\x12\x16\n\x0ejfrog_base_url\x18\x12 \x01(\t\"q\n InferenceJobConfigurationMessage\x12\x18\n\x10inference_job_id\x18\x01 \x01(\t\x12\x16\n\x0e\x65nvironment_id\x18\x02 \x01(\t\x12\x1b\n\x13\x63ustom_iam_role_arn\x18\x03 \x01(\t\"`\n\x0fModelIdentifier\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x10\n\x08\x62uild_id\x18\x02 \x01(\t\x12\x15\n\tbranch_id\x18\x03 \x01(\tB\x02\x18\x01\x12\x12\n\nmodel_uuid\x18\x04 \x01(\t\"\xa2\x01\n\x1dListFilesPreStepConfiguration\x12\x13\n\x0bsource_path\x18\x01 \x01(\t\x12\x1c\n\x14list_files_file_name\x18\x02 \x01(\t\x12\x1d\n\x15total_number_of_tasks\x18\x03 \x01(\x05\x12/\n\ntask_index\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\"\xf4\x04\n!InferenceTaskConfigurationMessage\x12\x15\n\rsource_bucket\x18\x01 \x01(\t\x12\x1a\n\x12\x64\x65stination_bucket\x18\x02 \x01(\t\x12\x10\n\x08\x66ilepath\x18\x03 \x01(\t\x12\x18\n\x10\x64\x65stination_path\x18\x04 \x01(\t\x12\x44\n\x0finput_file_type\x18\x05 \x01(\x0e\x32+.qwak.kube.deployment.captain.InputFileType\x12\x46\n\x10output_file_type\x18\x06 \x01(\x0e\x32,.qwak.kube.deployment.captain.OutputFileType\x12\x14\n\x0ctoken_secret\x18\x07 \x01(\t\x12\x15\n\rsecret_secret\x18\x08 \x01(\t\x12\x43\n\nparameters\x18\t \x03(\x0b\x32/.qwak.kube.deployment.captain.BatchJobParameter\x12\x43\n\x0e\x63loud_provider\x18\n \x01(\x0e\x32+.qwak.kube.deployment.captain.CloudProvider\x12\'\n\x1fservice_account_json_key_secret\x18\x0b \x01(\t\x12\x1a\n\x12is_point_file_path\x18\x0c \x01(\x08\x12\x66\n!list_files_pre_step_configuration\x18\r \x01(\x0b\x32;.qwak.kube.deployment.captain.ListFilesPreStepConfiguration\"/\n\x11\x42\x61tchJobParameter\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"?\n#CleanInferenceTasksExecutorsRequest\x12\x18\n\x10inference_job_id\x18\x01 \x01(\t\"O\n$CleanInferenceTasksExecutorsResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x16\n\x0e\x66\x61ilure_reason\x18\x02 \x01(\t\"X\n!CleanInferenceTaskExecutorRequest\x12\x18\n\x10inference_job_id\x18\x01 \x01(\t\x12\x19\n\x11inference_task_id\x18\x02 \x01(\t\"M\n\"CleanInferenceTaskExecutorResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x16\n\x0e\x66\x61ilure_reason\x18\x02 \x01(\t\"N\n#CreateInferenceTaskExecutorResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x16\n\x0e\x66\x61ilure_reason\x18\x02 \x01(\t\"\xf7\x02\n\x1eStartInferenceJobWarmupRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x15\n\tbranch_id\x18\x02 \x01(\tB\x02\x18\x01\x12\x10\n\x08\x62uild_id\x18\x03 \x01(\t\x12\x11\n\timage_url\x18\x04 \x01(\t\x12\x0f\n\x03\x63pu\x18\x05 \x01(\x02\x42\x02\x18\x01\x12\x19\n\rmemory_amount\x18\x06 \x01(\x05\x42\x02\x18\x01\x12\x45\n\x0cmemory_units\x18\x07 \x01(\x0e\x32+.qwak.kube.deployment.captain.MemoryUnitApiB\x02\x18\x01\x12\x11\n\texecutors\x18\x08 \x01(\x05\x12\x0f\n\x07timeout\x18\t \x01(\x05\x12\x41\n\x08job_size\x18\n \x01(\x0b\x32/.qwak.kube.deployment.captain.BatchJobResources\x12\x12\n\nmodel_uuid\x18\x0b \x01(\t\x12\x19\n\x11image_pull_secret\x18\x0c \x01(\t\"!\n\x1fStartInferenceJobWarmupResponse\"p\n\x1f\x43\x61ncelInferenceJobWarmupRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x15\n\tbranch_id\x18\x02 \x01(\tB\x02\x18\x01\x12\x10\n\x08\x62uild_id\x18\x03 \x01(\t\x12\x12\n\nmodel_uuid\x18\x04 \x01(\t\"\"\n CancelInferenceJobWarmupResponse\"\xd5\x01\n\x11\x42\x61tchJobResources\x12\x16\n\x0enumber_of_pods\x18\x01 \x01(\x05\x12\x0b\n\x03\x63pu\x18\x02 \x01(\x02\x12\x15\n\rmemory_amount\x18\x03 \x01(\x05\x12\x41\n\x0cmemory_units\x18\x04 \x01(\x0e\x32+.qwak.kube.deployment.captain.MemoryUnitApi\x12\x41\n\rgpu_resources\x18\x05 \x01(\x0b\x32*.qwak.kube.deployment.captain.GpuResources\"[\n\x0cGpuResources\x12\x37\n\x08gpu_type\x18\x01 \x01(\x0e\x32%.qwak.kube.deployment.captain.GpuType\x12\x12\n\ngpu_amount\x18\x02 \x01(\x05*:\n\rMemoryUnitApi\x12\x17\n\x13UNKNOWN_MEMORY_UNIT\x10\x00\x12\x07\n\x03MIB\x10\x01\x12\x07\n\x03GIB\x10\x02*\x81\x01\n\rInputFileType\x12\x1d\n\x19UNDEFINED_INPUT_FILE_TYPE\x10\x00\x12\x17\n\x13\x43SV_INPUT_FILE_TYPE\x10\x01\x12\x1b\n\x17\x46\x45\x41THER_INPUT_FILE_TYPE\x10\x02\x12\x1b\n\x17PARQUET_INPUT_FILE_TYPE\x10\x03*\x86\x01\n\x0eOutputFileType\x12\x1e\n\x1aUNDEFINED_OUTPUT_FILE_TYPE\x10\x00\x12\x18\n\x14\x43SV_OUTPUT_FILE_TYPE\x10\x01\x12\x1c\n\x18\x46\x45\x41THER_OUTPUT_FILE_TYPE\x10\x02\x12\x1c\n\x18PARQUET_OUTPUT_FILE_TYPE\x10\x03*\x90\x02\n\x07GpuType\x12\x0f\n\x0bINVALID_GPU\x10\x00\x12\x0e\n\nNVIDIA_K80\x10\x01\x12\x0f\n\x0bNVIDIA_V100\x10\x02\x12\x0f\n\x0bNVIDIA_A100\x10\x03\x12\r\n\tNVIDIA_T4\x10\x04\x12\x0f\n\x0bNVIDIA_A10G\x10\x05\x12\r\n\tNVIDIA_L4\x10\x06\x12\x14\n\x10NVIDIA_T4_1_4_15\x10\x07\x12\x14\n\x10NVIDIA_T4_1_8_30\x10\x08\x12\x15\n\x11NVIDIA_T4_1_16_60\x10\t\x12\x1e\n\x1aNVIDIA_A100_80GB_8_96_1360\x10\n\x12\x16\n\x12NVIDIA_V100_1_8_52\x10\x0b\x12\x18\n\x14NVIDIA_V100_4_32_208\x10\x0c*=\n\rCloudProvider\x12\x1a\n\x16UNKNOWN_CLOUD_PROVIDER\x10\x00\x12\x07\n\x03\x41WS\x10\x01\x12\x07\n\x03GCP\x10\x02\x42+\n\'com.qwak.ai.kube.deployment.captain.apiP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.kube_deployment_captain.batch_job_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\'com.qwak.ai.kube.deployment.captain.apiP\001'
  _LISTINFERENCEJOBFILESREQUEST.fields_by_name['token_secret']._options = None
  _LISTINFERENCEJOBFILESREQUEST.fields_by_name['token_secret']._serialized_options = b'\030\001'
  _LISTINFERENCEJOBFILESREQUEST.fields_by_name['secret_secret']._options = None
  _LISTINFERENCEJOBFILESREQUEST.fields_by_name['secret_secret']._serialized_options = b'\030\001'
  _LISTINFERENCEJOBFILESREQUEST.fields_by_name['role_arn']._options = None
  _LISTINFERENCEJOBFILESREQUEST.fields_by_name['role_arn']._serialized_options = b'\030\001'
  _TASKEXECUTORCONFIGURATIONMESSAGE.fields_by_name['cpu']._options = None
  _TASKEXECUTORCONFIGURATIONMESSAGE.fields_by_name['cpu']._serialized_options = b'\030\001'
  _TASKEXECUTORCONFIGURATIONMESSAGE.fields_by_name['memory_amount']._options = None
  _TASKEXECUTORCONFIGURATIONMESSAGE.fields_by_name['memory_amount']._serialized_options = b'\030\001'
  _TASKEXECUTORCONFIGURATIONMESSAGE.fields_by_name['memory_units']._options = None
  _TASKEXECUTORCONFIGURATIONMESSAGE.fields_by_name['memory_units']._serialized_options = b'\030\001'
  _MODELIDENTIFIER.fields_by_name['branch_id']._options = None
  _MODELIDENTIFIER.fields_by_name['branch_id']._serialized_options = b'\030\001'
  _STARTINFERENCEJOBWARMUPREQUEST.fields_by_name['branch_id']._options = None
  _STARTINFERENCEJOBWARMUPREQUEST.fields_by_name['branch_id']._serialized_options = b'\030\001'
  _STARTINFERENCEJOBWARMUPREQUEST.fields_by_name['cpu']._options = None
  _STARTINFERENCEJOBWARMUPREQUEST.fields_by_name['cpu']._serialized_options = b'\030\001'
  _STARTINFERENCEJOBWARMUPREQUEST.fields_by_name['memory_amount']._options = None
  _STARTINFERENCEJOBWARMUPREQUEST.fields_by_name['memory_amount']._serialized_options = b'\030\001'
  _STARTINFERENCEJOBWARMUPREQUEST.fields_by_name['memory_units']._options = None
  _STARTINFERENCEJOBWARMUPREQUEST.fields_by_name['memory_units']._serialized_options = b'\030\001'
  _CANCELINFERENCEJOBWARMUPREQUEST.fields_by_name['branch_id']._options = None
  _CANCELINFERENCEJOBWARMUPREQUEST.fields_by_name['branch_id']._serialized_options = b'\030\001'
  _globals['_MEMORYUNITAPI']._serialized_start=4761
  _globals['_MEMORYUNITAPI']._serialized_end=4819
  _globals['_INPUTFILETYPE']._serialized_start=4822
  _globals['_INPUTFILETYPE']._serialized_end=4951
  _globals['_OUTPUTFILETYPE']._serialized_start=4954
  _globals['_OUTPUTFILETYPE']._serialized_end=5088
  _globals['_GPUTYPE']._serialized_start=5091
  _globals['_GPUTYPE']._serialized_end=5363
  _globals['_CLOUDPROVIDER']._serialized_start=5365
  _globals['_CLOUDPROVIDER']._serialized_end=5426
  _globals['_LISTINFERENCEJOBFILESREQUEST']._serialized_start=111
  _globals['_LISTINFERENCEJOBFILESREQUEST']._serialized_end=577
  _globals['_GROUPEDTASKDETAILS']._serialized_start=579
  _globals['_GROUPEDTASKDETAILS']._serialized_end=678
  _globals['_CLEANSTORAGEOBJECTFROMCLOUDSTORAGEREQUEST']._serialized_start=681
  _globals['_CLEANSTORAGEOBJECTFROMCLOUDSTORAGEREQUEST']._serialized_end=989
  _globals['_AWSCREDENTIALS']._serialized_start=991
  _globals['_AWSCREDENTIALS']._serialized_end=1070
  _globals['_GCPCREDENTIALS']._serialized_start=1072
  _globals['_GCPCREDENTIALS']._serialized_end=1129
  _globals['_LISTINFERENCEJOBFILESRESPONSE']._serialized_start=1132
  _globals['_LISTINFERENCEJOBFILESRESPONSE']._serialized_end=1298
  _globals['_LISTFILEDETAILS']._serialized_start=1300
  _globals['_LISTFILEDETAILS']._serialized_end=1387
  _globals['_CREATEINFERENCETASKEXECUTORREQUEST']._serialized_start=1390
  _globals['_CREATEINFERENCETASKEXECUTORREQUEST']._serialized_end=1630
  _globals['_PREPAREINFERENCEJOBREQUEST']._serialized_start=1633
  _globals['_PREPAREINFERENCEJOBREQUEST']._serialized_end=1770
  _globals['_PREPAREINFERENCEJOBRESPONSE']._serialized_start=1772
  _globals['_PREPAREINFERENCEJOBRESPONSE']._serialized_end=1842
  _globals['_TASKEXECUTORCONFIGURATIONMESSAGE']._serialized_start=1845
  _globals['_TASKEXECUTORCONFIGURATIONMESSAGE']._serialized_end=2434
  _globals['_INFERENCEJOBCONFIGURATIONMESSAGE']._serialized_start=2436
  _globals['_INFERENCEJOBCONFIGURATIONMESSAGE']._serialized_end=2549
  _globals['_MODELIDENTIFIER']._serialized_start=2551
  _globals['_MODELIDENTIFIER']._serialized_end=2647
  _globals['_LISTFILESPRESTEPCONFIGURATION']._serialized_start=2650
  _globals['_LISTFILESPRESTEPCONFIGURATION']._serialized_end=2812
  _globals['_INFERENCETASKCONFIGURATIONMESSAGE']._serialized_start=2815
  _globals['_INFERENCETASKCONFIGURATIONMESSAGE']._serialized_end=3443
  _globals['_BATCHJOBPARAMETER']._serialized_start=3445
  _globals['_BATCHJOBPARAMETER']._serialized_end=3492
  _globals['_CLEANINFERENCETASKSEXECUTORSREQUEST']._serialized_start=3494
  _globals['_CLEANINFERENCETASKSEXECUTORSREQUEST']._serialized_end=3557
  _globals['_CLEANINFERENCETASKSEXECUTORSRESPONSE']._serialized_start=3559
  _globals['_CLEANINFERENCETASKSEXECUTORSRESPONSE']._serialized_end=3638
  _globals['_CLEANINFERENCETASKEXECUTORREQUEST']._serialized_start=3640
  _globals['_CLEANINFERENCETASKEXECUTORREQUEST']._serialized_end=3728
  _globals['_CLEANINFERENCETASKEXECUTORRESPONSE']._serialized_start=3730
  _globals['_CLEANINFERENCETASKEXECUTORRESPONSE']._serialized_end=3807
  _globals['_CREATEINFERENCETASKEXECUTORRESPONSE']._serialized_start=3809
  _globals['_CREATEINFERENCETASKEXECUTORRESPONSE']._serialized_end=3887
  _globals['_STARTINFERENCEJOBWARMUPREQUEST']._serialized_start=3890
  _globals['_STARTINFERENCEJOBWARMUPREQUEST']._serialized_end=4265
  _globals['_STARTINFERENCEJOBWARMUPRESPONSE']._serialized_start=4267
  _globals['_STARTINFERENCEJOBWARMUPRESPONSE']._serialized_end=4300
  _globals['_CANCELINFERENCEJOBWARMUPREQUEST']._serialized_start=4302
  _globals['_CANCELINFERENCEJOBWARMUPREQUEST']._serialized_end=4414
  _globals['_CANCELINFERENCEJOBWARMUPRESPONSE']._serialized_start=4416
  _globals['_CANCELINFERENCEJOBWARMUPRESPONSE']._serialized_end=4450
  _globals['_BATCHJOBRESOURCES']._serialized_start=4453
  _globals['_BATCHJOBRESOURCES']._serialized_end=4666
  _globals['_GPURESOURCES']._serialized_start=4668
  _globals['_GPURESOURCES']._serialized_end=4759
# @@protoc_insertion_point(module_scope)



import hashlib


def calculate_sha2(path: str) -> str:
    sha256 = hashlib.sha256()
    with open(path, "rb") as f:
        while chunk := f.read(8192):
            sha256.update(chunk)
    return sha256.hexdigest()


def calc_content_sha2(content: str) -> str:
    sha256 = hashlib.sha256()
    sha256.update(content.encode("utf-8"))
    return sha256.hexdigest()



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import qwak.execution.v1.backfill_pb2
import qwak.execution.v1.batch_pb2
import qwak.execution.v1.execution_pb2
import qwak.execution.v1.streaming_aggregation_pb2
import qwak.execution.v1.streaming_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class ListLastExecutionsForEnvironmentRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ListLastExecutionsForEnvironmentRequest = ListLastExecutionsForEnvironmentRequest

class ListLastExecutionsForEnvironmentResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class FeaturesetIdToLastExecutionEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> qwak.execution.v1.execution_pb2.ExecutionEntry: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: qwak.execution.v1.execution_pb2.ExecutionEntry | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    FEATURESET_ID_TO_LAST_EXECUTION_FIELD_NUMBER: builtins.int
    @property
    def featureset_id_to_last_execution(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, qwak.execution.v1.execution_pb2.ExecutionEntry]:
        """A map between the Featureset IDs of the environment and their respective last executions."""
    def __init__(
        self,
        *,
        featureset_id_to_last_execution: collections.abc.Mapping[builtins.str, qwak.execution.v1.execution_pb2.ExecutionEntry] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["featureset_id_to_last_execution", b"featureset_id_to_last_execution"]) -> None: ...

global___ListLastExecutionsForEnvironmentResponse = ListLastExecutionsForEnvironmentResponse

class TriggerBackfillRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BACKFILL_SPEC_FIELD_NUMBER: builtins.int
    @property
    def backfill_spec(self) -> qwak.execution.v1.backfill_pb2.BackfillSpec: ...
    def __init__(
        self,
        *,
        backfill_spec: qwak.execution.v1.backfill_pb2.BackfillSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["backfill_spec", b"backfill_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["backfill_spec", b"backfill_spec"]) -> None: ...

global___TriggerBackfillRequest = TriggerBackfillRequest

class TriggerBackfillResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXECUTION_ID_FIELD_NUMBER: builtins.int
    execution_id: builtins.str
    def __init__(
        self,
        *,
        execution_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["execution_id", b"execution_id"]) -> None: ...

global___TriggerBackfillResponse = TriggerBackfillResponse

class GetExecutionStatusRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXECUTION_ID_FIELD_NUMBER: builtins.int
    execution_id: builtins.str
    def __init__(
        self,
        *,
        execution_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["execution_id", b"execution_id"]) -> None: ...

global___GetExecutionStatusRequest = GetExecutionStatusRequest

class GetExecutionStatusResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXECUTION_STATUS_FIELD_NUMBER: builtins.int
    execution_status: qwak.execution.v1.execution_pb2.ExecutionStatus.ValueType
    def __init__(
        self,
        *,
        execution_status: qwak.execution.v1.execution_pb2.ExecutionStatus.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["execution_status", b"execution_status"]) -> None: ...

global___GetExecutionStatusResponse = GetExecutionStatusResponse

class GetExecutionEntryRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXECUTION_ID_FIELD_NUMBER: builtins.int
    execution_id: builtins.str
    def __init__(
        self,
        *,
        execution_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["execution_id", b"execution_id"]) -> None: ...

global___GetExecutionEntryRequest = GetExecutionEntryRequest

class GetExecutionEntryResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXECUTION_ENTRY_FIELD_NUMBER: builtins.int
    @property
    def execution_entry(self) -> qwak.execution.v1.execution_pb2.ExecutionEntry: ...
    def __init__(
        self,
        *,
        execution_entry: qwak.execution.v1.execution_pb2.ExecutionEntry | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["execution_entry", b"execution_entry"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["execution_entry", b"execution_entry"]) -> None: ...

global___GetExecutionEntryResponse = GetExecutionEntryResponse

class TriggerBatchFeaturesetRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BATCH_INGESTION_FIELD_NUMBER: builtins.int
    @property
    def batch_ingestion(self) -> qwak.execution.v1.batch_pb2.BatchIngestion: ...
    def __init__(
        self,
        *,
        batch_ingestion: qwak.execution.v1.batch_pb2.BatchIngestion | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["batch_ingestion", b"batch_ingestion"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["batch_ingestion", b"batch_ingestion"]) -> None: ...

global___TriggerBatchFeaturesetRequest = TriggerBatchFeaturesetRequest

class TriggerBatchFeaturesetResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXECUTION_ID_FIELD_NUMBER: builtins.int
    execution_id: builtins.str
    def __init__(
        self,
        *,
        execution_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["execution_id", b"execution_id"]) -> None: ...

global___TriggerBatchFeaturesetResponse = TriggerBatchFeaturesetResponse

class GetRunningExecutionEntriesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURESET_ID_FIELD_NUMBER: builtins.int
    featureset_id: builtins.str
    def __init__(
        self,
        *,
        featureset_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["featureset_id", b"featureset_id"]) -> None: ...

global___GetRunningExecutionEntriesRequest = GetRunningExecutionEntriesRequest

class GetRunningExecutionEntriesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXECUTION_ENTRIES_FIELD_NUMBER: builtins.int
    @property
    def execution_entries(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.execution.v1.execution_pb2.ExecutionEntry]: ...
    def __init__(
        self,
        *,
        execution_entries: collections.abc.Iterable[qwak.execution.v1.execution_pb2.ExecutionEntry] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["execution_entries", b"execution_entries"]) -> None: ...

global___GetRunningExecutionEntriesResponse = GetRunningExecutionEntriesResponse

class TriggerFeaturesetDeletionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURESET_ID_FIELD_NUMBER: builtins.int
    featureset_id: builtins.str
    def __init__(
        self,
        *,
        featureset_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["featureset_id", b"featureset_id"]) -> None: ...

global___TriggerFeaturesetDeletionRequest = TriggerFeaturesetDeletionRequest

class TriggerFeaturesetDeletionResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXECUTION_ID_FIELD_NUMBER: builtins.int
    execution_id: builtins.str
    def __init__(
        self,
        *,
        execution_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["execution_id", b"execution_id"]) -> None: ...

global___TriggerFeaturesetDeletionResponse = TriggerFeaturesetDeletionResponse

class InitPaginationByFeaturesetIdRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURESET_ID_FIELD_NUMBER: builtins.int
    featureset_id: builtins.str
    """the featureset id for which to start a pagination"""
    def __init__(
        self,
        *,
        featureset_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["featureset_id", b"featureset_id"]) -> None: ...

global___InitPaginationByFeaturesetIdRequest = InitPaginationByFeaturesetIdRequest

class InitPaginationByFeaturesetIdResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RECORD_COUNT_FIELD_NUMBER: builtins.int
    MAX_EXECUTION_INDEX_FIELD_NUMBER: builtins.int
    record_count: builtins.int
    """Number of executions found for this Featureset at the time of querying
    this is used mainly by the client to plan things like number of pages etc.
    """
    max_execution_index: builtins.int
    """the current highest execution index for this FS. this is the anchor
    to use on subsequent requests if the caller wants to achieve
    a view of a static list
    """
    def __init__(
        self,
        *,
        record_count: builtins.int = ...,
        max_execution_index: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["max_execution_index", b"max_execution_index", "record_count", b"record_count"]) -> None: ...

global___InitPaginationByFeaturesetIdResponse = InitPaginationByFeaturesetIdResponse

class ListExecutionsByFeaturesetIdRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURESET_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_NUMBER_FIELD_NUMBER: builtins.int
    MAX_EXECUTION_INDEX_FIELD_NUMBER: builtins.int
    featureset_id: builtins.str
    """featureset id"""
    page_size: builtins.int
    """The page size to use for the response - the number of results in the response
    is the minimum of the page_size and number of matching rows.
    - a negative value means all results will be returned (in that case page_number is ignored)
    """
    page_number: builtins.int
    """The page number to use"""
    max_execution_index: builtins.int
    """The max execution index to use as anchor - this is the value returned from InitPaginationByFeaturesetId"""
    def __init__(
        self,
        *,
        featureset_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_number: builtins.int = ...,
        max_execution_index: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["featureset_id", b"featureset_id", "max_execution_index", b"max_execution_index", "page_number", b"page_number", "page_size", b"page_size"]) -> None: ...

global___ListExecutionsByFeaturesetIdRequest = ListExecutionsByFeaturesetIdRequest

class ListExecutionsByFeaturesetIdResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXECUTION_ENTRIES_FIELD_NUMBER: builtins.int
    @property
    def execution_entries(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.execution.v1.execution_pb2.ExecutionEntry]: ...
    def __init__(
        self,
        *,
        execution_entries: collections.abc.Iterable[qwak.execution.v1.execution_pb2.ExecutionEntry] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["execution_entries", b"execution_entries"]) -> None: ...

global___ListExecutionsByFeaturesetIdResponse = ListExecutionsByFeaturesetIdResponse

class TriggerOnlineStreamingIngestionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ONLINE_STREAMING_INGESTION_FIELD_NUMBER: builtins.int
    @property
    def online_streaming_ingestion(self) -> qwak.execution.v1.streaming_pb2.OnlineStreamingIngestion: ...
    def __init__(
        self,
        *,
        online_streaming_ingestion: qwak.execution.v1.streaming_pb2.OnlineStreamingIngestion | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["online_streaming_ingestion", b"online_streaming_ingestion"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["online_streaming_ingestion", b"online_streaming_ingestion"]) -> None: ...

global___TriggerOnlineStreamingIngestionRequest = TriggerOnlineStreamingIngestionRequest

class TriggerOnlineStreamingIngestionResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXECUTION_ID_FIELD_NUMBER: builtins.int
    execution_id: builtins.str
    def __init__(
        self,
        *,
        execution_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["execution_id", b"execution_id"]) -> None: ...

global___TriggerOnlineStreamingIngestionResponse = TriggerOnlineStreamingIngestionResponse

class TriggerOfflineStreamingIngestionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OFFLINE_STREAMING_INGESTION_FIELD_NUMBER: builtins.int
    @property
    def offline_streaming_ingestion(self) -> qwak.execution.v1.streaming_pb2.OfflineStreamingIngestion: ...
    def __init__(
        self,
        *,
        offline_streaming_ingestion: qwak.execution.v1.streaming_pb2.OfflineStreamingIngestion | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["offline_streaming_ingestion", b"offline_streaming_ingestion"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["offline_streaming_ingestion", b"offline_streaming_ingestion"]) -> None: ...

global___TriggerOfflineStreamingIngestionRequest = TriggerOfflineStreamingIngestionRequest

class TriggerOfflineStreamingIngestionResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXECUTION_ID_FIELD_NUMBER: builtins.int
    execution_id: builtins.str
    def __init__(
        self,
        *,
        execution_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["execution_id", b"execution_id"]) -> None: ...

global___TriggerOfflineStreamingIngestionResponse = TriggerOfflineStreamingIngestionResponse

class TriggerRowLevelStreamingAggregationIngestionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROW_LEVEL_INGESTION_FIELD_NUMBER: builtins.int
    @property
    def row_level_ingestion(self) -> qwak.execution.v1.streaming_aggregation_pb2.RowLevelStreamingAggregationIngestion: ...
    def __init__(
        self,
        *,
        row_level_ingestion: qwak.execution.v1.streaming_aggregation_pb2.RowLevelStreamingAggregationIngestion | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["row_level_ingestion", b"row_level_ingestion"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["row_level_ingestion", b"row_level_ingestion"]) -> None: ...

global___TriggerRowLevelStreamingAggregationIngestionRequest = TriggerRowLevelStreamingAggregationIngestionRequest

class TriggerRowLevelStreamingAggregationIngestionResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXECUTION_ID_FIELD_NUMBER: builtins.int
    execution_id: builtins.str
    def __init__(
        self,
        *,
        execution_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["execution_id", b"execution_id"]) -> None: ...

global___TriggerRowLevelStreamingAggregationIngestionResponse = TriggerRowLevelStreamingAggregationIngestionResponse

class TriggerCompactionStreamingAggregationIngestionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMPACTION_INGESTION_FIELD_NUMBER: builtins.int
    @property
    def compaction_ingestion(self) -> qwak.execution.v1.streaming_aggregation_pb2.CompactionStreamingAggregationIngestion: ...
    def __init__(
        self,
        *,
        compaction_ingestion: qwak.execution.v1.streaming_aggregation_pb2.CompactionStreamingAggregationIngestion | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["compaction_ingestion", b"compaction_ingestion"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["compaction_ingestion", b"compaction_ingestion"]) -> None: ...

global___TriggerCompactionStreamingAggregationIngestionRequest = TriggerCompactionStreamingAggregationIngestionRequest

class TriggerCompactionStreamingAggregationIngestionResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXECUTION_ID_FIELD_NUMBER: builtins.int
    execution_id: builtins.str
    def __init__(
        self,
        *,
        execution_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["execution_id", b"execution_id"]) -> None: ...

global___TriggerCompactionStreamingAggregationIngestionResponse = TriggerCompactionStreamingAggregationIngestionResponse

class TriggerStreamingAggregationBackfillRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BACKFILL_FIELD_NUMBER: builtins.int
    @property
    def backfill(self) -> qwak.execution.v1.streaming_aggregation_pb2.StreamingAggregationBackfillIngestion: ...
    def __init__(
        self,
        *,
        backfill: qwak.execution.v1.streaming_aggregation_pb2.StreamingAggregationBackfillIngestion | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["backfill", b"backfill"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["backfill", b"backfill"]) -> None: ...

global___TriggerStreamingAggregationBackfillRequest = TriggerStreamingAggregationBackfillRequest

class TriggerStreamingAggregationBackfillResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXECUTION_ID_FIELD_NUMBER: builtins.int
    execution_id: builtins.str
    def __init__(
        self,
        *,
        execution_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["execution_id", b"execution_id"]) -> None: ...

global___TriggerStreamingAggregationBackfillResponse = TriggerStreamingAggregationBackfillResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import qwak.feature_store.entities.entity_pb2
import qwak.feature_store.features.feature_set_types_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class StreamingAggregationFeaturesetMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    FEATURESET_NAME_FIELD_NUMBER: builtins.int
    FEATURESET_ID_FIELD_NUMBER: builtins.int
    STREAMING_AGGREGATION_FEATURESET_FIELD_NUMBER: builtins.int
    ENTITY_FIELD_NUMBER: builtins.int
    AVRO_SCHEMA_JSON_FIELD_NUMBER: builtins.int
    environment_id: builtins.str
    """Multi environment support"""
    featureset_name: builtins.str
    """Featureset name"""
    featureset_id: builtins.str
    """Featureset id"""
    @property
    def streaming_aggregation_featureset(self) -> qwak.feature_store.features.feature_set_types_pb2.StreamingAggregationFeatureSet:
        """Streaming aggregation featureset"""
    @property
    def entity(self) -> qwak.feature_store.entities.entity_pb2.EntityDefinition:
        """Entity definition of the FeatureSet"""
    avro_schema_json: builtins.str
    """The avro schema in json format that represents the AggregationSpec"""
    def __init__(
        self,
        *,
        environment_id: builtins.str = ...,
        featureset_name: builtins.str = ...,
        featureset_id: builtins.str = ...,
        streaming_aggregation_featureset: qwak.feature_store.features.feature_set_types_pb2.StreamingAggregationFeatureSet | None = ...,
        entity: qwak.feature_store.entities.entity_pb2.EntityDefinition | None = ...,
        avro_schema_json: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["entity", b"entity", "streaming_aggregation_featureset", b"streaming_aggregation_featureset"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["avro_schema_json", b"avro_schema_json", "entity", b"entity", "environment_id", b"environment_id", "featureset_id", b"featureset_id", "featureset_name", b"featureset_name", "streaming_aggregation_featureset", b"streaming_aggregation_featureset"]) -> None: ...

global___StreamingAggregationFeaturesetMetadata = StreamingAggregationFeaturesetMetadata

class BatchFeaturesetV1Metadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    FEATURESET_NAME_FIELD_NUMBER: builtins.int
    FEATURESET_ID_FIELD_NUMBER: builtins.int
    QWAK_PROTOCOL_VERSION_FIELD_NUMBER: builtins.int
    BATCH_FEATURESET_V1_FIELD_NUMBER: builtins.int
    ENTITY_FIELD_NUMBER: builtins.int
    environment_id: builtins.str
    """Multi environment support"""
    featureset_name: builtins.str
    """Featureset name"""
    featureset_id: builtins.str
    """Featureset id"""
    qwak_protocol_version: builtins.int
    """qwak protocol version"""
    @property
    def batch_featureset_v1(self) -> qwak.feature_store.features.feature_set_types_pb2.BatchFeatureSetV1:
        """batch v1 featureset"""
    @property
    def entity(self) -> qwak.feature_store.entities.entity_pb2.EntityDefinition:
        """Entity definition of the FeatureSet"""
    def __init__(
        self,
        *,
        environment_id: builtins.str = ...,
        featureset_name: builtins.str = ...,
        featureset_id: builtins.str = ...,
        qwak_protocol_version: builtins.int = ...,
        batch_featureset_v1: qwak.feature_store.features.feature_set_types_pb2.BatchFeatureSetV1 | None = ...,
        entity: qwak.feature_store.entities.entity_pb2.EntityDefinition | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["batch_featureset_v1", b"batch_featureset_v1", "entity", b"entity"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["batch_featureset_v1", b"batch_featureset_v1", "entity", b"entity", "environment_id", b"environment_id", "featureset_id", b"featureset_id", "featureset_name", b"featureset_name", "qwak_protocol_version", b"qwak_protocol_version"]) -> None: ...

global___BatchFeaturesetV1Metadata = BatchFeaturesetV1Metadata

class StreamingFeaturesetV1Metadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    FEATURESET_NAME_FIELD_NUMBER: builtins.int
    FEATURESET_ID_FIELD_NUMBER: builtins.int
    QWAK_PROTOCOL_VERSION_FIELD_NUMBER: builtins.int
    STREAMING_FEATURESET_V1_FIELD_NUMBER: builtins.int
    ENTITY_FIELD_NUMBER: builtins.int
    environment_id: builtins.str
    """Multi environment support"""
    featureset_name: builtins.str
    """Featureset name"""
    featureset_id: builtins.str
    """Featureset id"""
    qwak_protocol_version: builtins.int
    """qwak protocol version"""
    @property
    def streaming_featureset_v1(self) -> qwak.feature_store.features.feature_set_types_pb2.StreamingFeatureSetV1:
        """Streaming v1 featureset"""
    @property
    def entity(self) -> qwak.feature_store.entities.entity_pb2.EntityDefinition:
        """Entity definition of the FeatureSet"""
    def __init__(
        self,
        *,
        environment_id: builtins.str = ...,
        featureset_name: builtins.str = ...,
        featureset_id: builtins.str = ...,
        qwak_protocol_version: builtins.int = ...,
        streaming_featureset_v1: qwak.feature_store.features.feature_set_types_pb2.StreamingFeatureSetV1 | None = ...,
        entity: qwak.feature_store.entities.entity_pb2.EntityDefinition | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["entity", b"entity", "streaming_featureset_v1", b"streaming_featureset_v1"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["entity", b"entity", "environment_id", b"environment_id", "featureset_id", b"featureset_id", "featureset_name", b"featureset_name", "qwak_protocol_version", b"qwak_protocol_version", "streaming_featureset_v1", b"streaming_featureset_v1"]) -> None: ...

global___StreamingFeaturesetV1Metadata = StreamingFeaturesetV1Metadata

class FeaturesetMemoryUsageStats(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    FEATURESET_ID_FIELD_NUMBER: builtins.int
    FEATURESET_NAME_FIELD_NUMBER: builtins.int
    ONLINE_USED_BYTES_FIELD_NUMBER: builtins.int
    environment_id: builtins.str
    """environment id"""
    featureset_id: builtins.str
    """featureset id"""
    featureset_name: builtins.str
    """featureset name"""
    online_used_bytes: builtins.int
    """number of bytes used in the online store"""
    def __init__(
        self,
        *,
        environment_id: builtins.str = ...,
        featureset_id: builtins.str = ...,
        featureset_name: builtins.str = ...,
        online_used_bytes: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment_id", b"environment_id", "featureset_id", b"featureset_id", "featureset_name", b"featureset_name", "online_used_bytes", b"online_used_bytes"]) -> None: ...

global___FeaturesetMemoryUsageStats = FeaturesetMemoryUsageStats
